@@ -327,7 +327,7 @@ static void comli_prepare(raw_data_t *dest, const comli_head_t *h, const void *b
 
 
 	/* it's caller responsibility to allocate enough space.
-	   else it is a bug in the program */
+	 * else it is a bug in the program */
 	if ( (out+11+count+2) > (dest->buf + dest->buf_size) )
 		fatalx(EXIT_FAILURE, "too small dest in comli_prepare\n");
 
@@ -1003,9 +1003,11 @@ static int al175_read(byte_t *dst, size_t addr, size_t count)
 	if (err==-1)
 		return -1;
 
-	if ((rx_data.end - rx_data.begin) < 0 ||
-	    (size_t)(rx_data.end - rx_data.begin) != count)
+	if ((rx_data.end - rx_data.begin) < 0
+	 || (size_t)(rx_data.end - rx_data.begin) != count
+	) {
 		return -1;
+	}
 
 	if ( (io.addr != addr) || (io.len != count) ) {
 		upsdebugx(3, "%s: io_head mismatch\t(%" PRIxSIZE ",%" PRIxSIZE " != %" PRIxSIZE ",%" PRIxSIZE ")",
@@ -1276,7 +1278,7 @@ void upsdrv_shutdown(void)
 	/* tell the UPS to shut down, then return - DO NOT SLEEP HERE */
 
 	/* maybe try to detect the UPS here, but try a shutdown even if
-	   it doesn't respond at first if possible */
+	 * it doesn't respond at first if possible */
 
 	/* replace with a proper shutdown function */
 	upslogx(LOG_ERR, "shutdown not supported");
@@ -1284,7 +1286,7 @@ void upsdrv_shutdown(void)
 		set_exit_flag(EF_EXIT_FAILURE);
 
 	/* you may have to check the line status since the commands
-	   for toggling power are frequently different for OL vs. OB */
+	 * for toggling power are frequently different for OL vs. OB */
 
 	/* OL: this must power cycle the load if possible */
 
