@@ -45,7 +45,7 @@
 #include "serial.h"
 
 #define DRIVER_NAME	"Best Ferrups/Fortress driver"
-#define DRIVER_VERSION	"0.16"
+#define DRIVER_VERSION	"0.18"
 
 /* driver description structure */
 upsdrv_info_t upsdrv_info = {
@@ -456,7 +456,7 @@ static void ups_sync(void)
 	char buf[256];
 
 	/* A bit better sanity might be good here. As is, we expect the
-	 human to observe the time being totally not a time. */
+	 * human to observe the time being totally not a time. */
 
 	if (execute("time\r", buf, sizeof(buf)) > 0) {
 		upsdebugx(1, "UPS Time: %s", buf);
@@ -472,9 +472,13 @@ static void ups_sync(void)
 static
 int instcmd(const char *cmdname, const char *extra)
 {
+	/* May be used in logging below, but not as a command argument */
 	NUT_UNUSED_VARIABLE(extra);
+	upsdebug_INSTCMD_STARTING(cmdname, extra);
 
 	if (!strcasecmp(cmdname, "shutdown.return")) {
+		upslog_INSTCMD_POWERSTATE_CHANGE(cmdname, extra);
+
 		/* NB: hard-wired password */
 		ser_send(upsfd, "pw377\r");
 		/* power off in 10 seconds and restart when line power returns,
@@ -484,7 +488,7 @@ int instcmd(const char *cmdname, const char *extra)
 		return STAT_INSTCMD_HANDLED;
 	}
 
-	upslogx(LOG_NOTICE, "instcmd: unknown command [%s] [%s]", cmdname, extra);
+	upslog_INSTCMD_UNKNOWN(cmdname, extra);
 	return STAT_INSTCMD_UNKNOWN;
 }
 
@@ -508,6 +512,11 @@ void upsdrv_help(void)
 {
 }
 
+/* optionally tweak prognames[] entries */
+void upsdrv_tweak_prognames(void)
+{
+}
+
 static void sync_serial(void) {
 	char buffer[10];
 
@@ -597,7 +606,7 @@ static void upsdrv_init_nofc(void)
 	upsdebugx(2, "id response: %s", rstring);
 
 	/* Better way to identify this unit is using "d 15\r", which results in
-	   "15 M#	 MD1KVA", "id\r" yields "Unit ID "C1K03588"" */
+	 * "15 M#	 MD1KVA", "id\r" yields "Unit ID "C1K03588"" */
 	if (strstr(rstring, "Unit ID \"C1K")){
 		fc.model = MDxxxx;
 		snprintf(fc.name, sizeof(fc.name), "%s", "Micro Ferrups");
