@@ -748,8 +748,8 @@ static int ups2000_update_status(void)
 			 * if the register is equal to the "val" we are looking
 			 * for, or if register has its n-th "bit" set...
 			 */
-			if ((flag[j].val != -1 && flag[j].val == val) ||
-			    (flag[j].bit != -1 && CHECK_BIT(val, flag[j].bit))
+			if ((flag[j].val != -1 && flag[j].val == val)
+			 || (flag[j].bit != -1 && CHECK_BIT(val, flag[j].bit))
 			) {
 				/* if it has a corresponding status flag */
 				if (strlen(flag[j].status_name) != 0)
@@ -983,7 +983,7 @@ static int ups2000_update_alarm(void)
 
 			alarm_count++;
 
-			gotlen = snprintf(alarm_buf, 128, "(ID %02d/%02d): %s!",
+			gotlen = snprintf(alarm_buf, sizeof(alarm_buf), "(ID %02d/%02d): %s!",
 				ups2000_alarm[i].alarm_id,
 				ups2000_alarm[i].alarm_cause_id,
 				ups2000_alarm[i].alarm_name);
@@ -1002,8 +1002,8 @@ static int ups2000_update_alarm(void)
 			 * Log the warning only if it's a new alarm, or if a long time
 			 * has paseed since we first warned it.
 			 */
-			if (!ups2000_alarm[i].active ||
-			    difftime(now, alarm_logged_since) >= UPS2000_LOG_INTERVAL
+			if (!ups2000_alarm[i].active
+			 || difftime(now, alarm_logged_since) >= UPS2000_LOG_INTERVAL
 			) {
 				int loglevel;
 				const char *alarm_word;
@@ -1073,7 +1073,7 @@ static int ups2000_update_alarm(void)
 
 	if (alarm_count > 0) {
 		/* append this to the alarm string as a friendly reminder */
-		int gotlen = snprintf(alarm_buf, 128, "Check log for details!");
+		int gotlen = snprintf(alarm_buf, sizeof(alarm_buf), "Check log for details!");
 
 		if (gotlen < 0 || (uintmax_t)gotlen > SIZE_MAX) {
 			fatalx(EXIT_FAILURE, "alarm_buf preparation over/under-flow!");
@@ -1085,8 +1085,9 @@ static int ups2000_update_alarm(void)
 		/* if the alarm string is too long, replace it with this */
 		if (all_alarms_len + 1 > ST_MAX_VALUE_LEN) {
 			alarm_init();  /* discard all original alarms */
-			snprintf(alarm_buf, 128, "UPS has %d alarms in effect, "
-						 "check log for details!", alarm_count);
+			snprintf(alarm_buf, sizeof(alarm_buf),
+				"UPS has %d alarms in effect, "
+				"check log for details!", alarm_count);
 			alarm_set(alarm_buf);
 		}
 
@@ -2018,8 +2019,9 @@ static int ups2000_read_registers(modbus_t *ctx, int addr, int nb, uint16_t *des
 		 * this register returns invalid values. This is a known problem
 		 * and it's not fatal, so we use LOG_INFO.
 		 */
-		if (retry_status == RETRY_ENABLE &&
-		    addr == 12002 && (dest[0] < 2 || dest[0] > 5)
+		if (retry_status == RETRY_ENABLE
+		 && addr == 12002
+		 && (dest[0] < 2 || dest[0] > 5)
 		) {
 			upslogx(LOG_INFO, "Battery status has a non-fatal read failure, it's usually harmless. Retrying... ");
 			sleep(1);
