@@ -1,6 +1,6 @@
 /*!
  * @file libhid.c
- * @brief HID Library - User API (Generic HID Access using MGE HIDParser)
+ * @brief NUT HID Library - User API (Generic HID Access using MGE HIDParser)
  *
  * @author Copyright (C) 2003 - 2007
  *	Arnaud Quette <arnaud.quette@free.fr> && <arnaud.quette@mgeups.com>
@@ -39,7 +39,7 @@
 #ifdef HAVE_STRINGS_H
 # include <strings.h>
 #endif
-/* #include <math.h> */
+/* #include "nut_float.h" */
 #include "libhid.h"
 #include "hidparser.h"
 #include "common.h" /* for xmalloc, upsdebugx prototypes */
@@ -47,10 +47,10 @@
 
 /* Communication layers and drivers (USB and MGE SHUT) */
 #if (defined SHUT_MODE) && SHUT_MODE
-	#include "libshut.h"
+#	include "libshut.h"
 	communication_subdriver_t *comm_driver = &shut_subdriver;
 #else	/* !SHUT_MODE => USB */
-	#include "nut_libusb.h"
+#	include "nut_libusb.h"
 	communication_subdriver_t *comm_driver = &usb_subdriver;
 #endif	/* SHUT_MODE / USB */
 
@@ -228,6 +228,8 @@ static int refresh_report_buffer(reportbuf_t *rbuf, hid_dev_handle_t udev, HIDDa
 # pragma GCC diagnostic pop
 #endif
 
+	upsdebugx(5, "%s: investigating path: %s",
+		__func__, HIDGetDataItem(pData, NULL));
 	ret = comm_driver->get_report(udev, id,
 		(usb_ctrl_charbuf)rbuf->data[id],
 		(usb_ctrl_charbufsize)r);
@@ -239,7 +241,7 @@ static int refresh_report_buffer(reportbuf_t *rbuf, hid_dev_handle_t udev, HIDDa
 	r = (size_t)ret;
 
 	if (rbuf->len[id] != r) {
-		/* e.g. if maxreportsize flag was set */
+		/* e.g. if max_report_size flag was set */
 		upsdebugx(2,
 			"%s: expected %" PRIuSIZE " bytes, but got %" PRIuSIZE " instead",
 			__func__, rbuf->len[id], r);
@@ -487,15 +489,22 @@ const char *HIDDataType(const HIDData_t *hiddata)
 HIDData_t *HIDGetItemData(const char *hidpath, usage_tables_t *utab)
 {
 	int	r;
-	HIDPath_t Path;
+	HIDPath_t	Path;
+	HIDData_t	*p;
 
 	r = string_to_path(hidpath, &Path, utab);
 	if (r <= 0) {
+		upsdebugx(4, "%s: string_to_path() failed to decipher '%s'", __func__, hidpath);
 		return NULL;
 	}
 
 	/* Get info on object (reportID, offset and size) */
-	return FindObject_with_Path(pDesc, &Path, interrupt_only ? ITEM_INPUT:ITEM_FEATURE);
+	p = FindObject_with_Path(pDesc, &Path, interrupt_only ? ITEM_INPUT:ITEM_FEATURE);
+
+	if (!p)
+		upsdebugx(4, "%s: FindObject_with_Path() failed to locate '%s'", __func__, hidpath);
+
+	return p;
 }
 
 char *HIDGetDataItem(const HIDData_t *hiddata, usage_tables_t *utab)
@@ -550,6 +559,7 @@ int HIDGetItemValue(hid_dev_handle_t udev, const char *hidpath, double *Value, u
 char *HIDGetIndexString(hid_dev_handle_t udev, const int Index, char *buf, size_t buflen)
 {
 	usb_ctrl_strindex	idx;
+	int	ret;
 
 #if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && ( (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_TYPE_LIMITS) || (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_TAUTOLOGICAL_CONSTANT_OUT_OF_RANGE_COMPARE) || (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_TAUTOLOGICAL_UNSIGNED_ZERO_COMPARE) || (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_UNREACHABLE_CODE) || (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_TAUTOLOGICAL_TYPE_LIMIT_COMPARE) )
 # pragma GCC diagnostic push
@@ -617,8 +627,15 @@ char *HIDGetIndexString(hid_dev_handle_t udev, const int Index, char *buf, size_
 # pragma GCC diagnostic pop
 #endif
 
-	if (comm_driver->get_string(udev, idx, buf, (usb_ctrl_charbufsize)buflen) < 1)
+	ret = comm_driver->get_string(udev, idx, buf, (usb_ctrl_charbufsize)buflen);
+	upsdebugx(6, "%s: get_string() at index %d returned %d %s",
+		__func__, Index, ret,
+		ret < 0 ? "error code" : "useful bytes");
+	if (ret < 1)
 		buf[0] = '\0';
+	else
+		upsdebug_hex(6, "...into data buffer", buf,
+			((size_t)ret < buflen ? (size_t)ret : buflen));
 
 	return str_rtrim(buf, '\n');
 }
@@ -980,7 +997,9 @@ badvalue:
 	return i;
 }
 
-/* translate HID numeric path to string path and return path depth */
+/* translate HID numeric path to string path and return path depth
+ * can pass utab=NULL to leave it a chain of HEX strings
+ */
 static int path_to_string(char *string, size_t size, const HIDPath_t *path, usage_tables_t *utab)
 {
 	int	i;
@@ -994,7 +1013,7 @@ static int path_to_string(char *string, size_t size, const HIDPath_t *path, usag
 			snprintfcat(string, size, ".");
 
 		/* lookup tables first (to override defaults) */
-		if ((p = hid_lookup_path(path->Node[i], utab)) != NULL)
+		if (utab != NULL && ((p = hid_lookup_path(path->Node[i], utab)) != NULL))
 		{
 			snprintfcat(string, size, "%s", p);
 			continue;
@@ -1003,7 +1022,7 @@ static int path_to_string(char *string, size_t size, const HIDPath_t *path, usag
 		/* indexed collection */
 		if ((path->Node[i] & 0xffff0000) == 0x00ff0000)
 		{
-			snprintfcat(string, size, "[%i]", path->Node[i] & 0x0000ffff);
+			snprintfcat(string, size, "[%u]", path->Node[i] & 0x0000ffff);
 			continue;
 		}
 
