@@ -37,7 +37,7 @@
 
 #ifdef WIN32
 #include "wincompat.h"
-#endif
+#endif	/* WIN32 */
 
 #define MGE_XML_VERSION		"MGEXML/0.36"
 
@@ -73,8 +73,8 @@ static int	mge_report_deprecation__convert_deci = 1;
 typedef enum {
 	ROOTPARENT = NE_XML_STATEROOT,
 
-	_UNEXPECTED,
-	_PARSEERROR,
+	NETXML_UNEXPECTED,
+	NETXML_PARSEERROR,
 
 	PRODUCT_INFO = 100,	/* "/mgeups/product.xml" */
 
@@ -132,7 +132,7 @@ typedef struct {
 	uint32_t xmlflags;	/* XML flags (to be used to determine what kind of variable this is */
 	size_t	xmllen;		/* length of the XML string */
 	const char	*(*convert)(const char *value);	/* conversion function from XML<->NUT value (returns
-						   NULL if no further processing is required) */
+							 * NULL if no further processing is required) */
 } xml_info_t;
 
 static const char *online_info(const char *arg_val)
@@ -510,6 +510,8 @@ static const char *mge_beeper_info(const char *arg_val)
 		return "enabled";
 	case 3:
 		return "muted";
+	default:
+		break;
 	}
 	return NULL;
 }
@@ -528,6 +530,8 @@ static const char *mge_upstype_conversion(const char *arg_val)
 		return "online - parallel with hot standy";
 	case 5:
 		return "online - hot standby redundancy";
+	default:
+		break;
 	}
 	return NULL;
 }
@@ -542,6 +546,8 @@ static const char *mge_sensitivity_info(const char *arg_val)
 		return "high";
 	case 2:
 		return "low";
+	default:
+		break;
 	}
 	return NULL;
 }
@@ -566,6 +572,8 @@ static const char *mge_test_result_info(const char *arg_val)
 		return "no test initiated";
 	case 7:
 		return "test scheduled";
+	default:
+		break;
 	}
 	return NULL;
 }
@@ -1142,7 +1150,7 @@ static xml_info_t mge_xml2nut[] = {
 /* A start-element callback for element with given namespace/name. */
 static int mge_xml_startelm_cb(void *userdata, int parent, const char *nspace, const char *name, const char **atts)
 {
-	int	state = _UNEXPECTED;
+	int	state = NETXML_UNEXPECTED;
 	NUT_UNUSED_VARIABLE(userdata);
 	NUT_UNUSED_VARIABLE(nspace);
 
@@ -1416,6 +1424,10 @@ static int mge_xml_startelm_cb(void *userdata, int parent, const char *nspace, c
 			state = XC_BROADCAST;
 			break;
 		}
+		break;
+
+	default:
+		break;
 	}
 
 	upsdebugx(3, "%s: name <%s> (parent = %d, state = %d)", __func__, name, parent, state);
@@ -1445,6 +1457,9 @@ static int mge_xml_cdata_cb(void *userdata, int state, const char *cdata, size_t
 	case GO_OBJECT:
 		snprintfcat(val, sizeof(val), "%.*s", (int)len, cdata);
 		break;
+
+	default:
+		break;
 	}
 
 	return 0;
@@ -1517,6 +1532,9 @@ static int mge_xml_endelm_cb(void *userdata, int state, const char *nspace, cons
 			&inited_phaseinfo_out, &num_outphases, 0);
 
 		break;
+
+	default:
+		break;
 	}
 
 	return 0;
