@@ -28,7 +28,7 @@
 #include "main.h"		/* for getval() */
 #include "usb-common.h"
 
-#define OPENUPS_HID_VERSION	"openUPS HID 0.5"
+#define OPENUPS_HID_VERSION	"openUPS HID 0.50"
 
 /* Minibox */
 #define OPENUPS_VENDORID	0x04d8
@@ -63,6 +63,8 @@ static void *get_voltage_multiplier(USBDevice_t *device)
 			ccharge_scale = 0.1; /* unverified */
 			cdischarge_scale = 0.1; /* unverified */
 			break;
+		default:
+			break;
 	}
 
 	upsdebugx(1, "vin_scale = %g; vout_scale = %g\n", vin_scale, vout_scale);
@@ -126,7 +128,6 @@ static const unsigned int therm_tbl_size = SIZEOF_ARRAY(therm_tbl);
 static const char *openups_charging_fun(double value);
 static const char *openups_discharging_fun(double value);
 static const char *openups_online_fun(double value);
-static const char *openups_nobattery_fun(double value);
 static const char *openups_off_fun(double value);
 
 static const char *openups_scale_vin_fun(double value);
@@ -148,10 +149,6 @@ static info_lkp_t openups_online_info[] = {
 	{0, NULL, openups_online_fun, NULL }
 };
 
-static info_lkp_t openups_nobattery_info[] = {
-	{0, NULL, openups_nobattery_fun, NULL }
-};
-
 static info_lkp_t openups_off_info[] = {
 	{0, NULL, openups_off_fun, NULL }
 };
@@ -195,11 +192,6 @@ static const char *openups_online_fun(double value)
 	return value ? "online" : "!online";
 }
 
-static const char *openups_nobattery_fun(double value)
-{
-	return value ? "nobattery" : "!nobattery";
-}
-
 static const char *openups_off_fun(double value)
 {
 	return value ? "!off" : "off";
@@ -342,7 +334,7 @@ static hid_info_t openups_hid2nut[] = {
 	{"BOOL", 0, 0, "UPS.PowerSummary.PresentStatus.Discharging", NULL, NULL, HU_FLAG_QUICK_POLL, openups_discharging_info},
 	{"BOOL", 0, 0, "UPS.PowerSummary.PresentStatus.NeedReplacement", NULL, NULL, 0, replacebatt_info},
 	{"BOOL", 0, 0, "UPS.PowerSummary.PresentStatus.ACPresent", NULL, NULL, HU_FLAG_QUICK_POLL, openups_online_info},
-	{"BOOL", 0, 0, "UPS.PowerSummary.PresentStatus.BatteryPresent", NULL, NULL, HU_FLAG_QUICK_POLL, openups_nobattery_info},
+	{"BOOL", 0, 0, "UPS.PowerSummary.PresentStatus.BatteryPresent", NULL, NULL, HU_FLAG_QUICK_POLL, nobattery_info},
 
 	/* end of structure. */
 	{NULL, 0, 0, NULL, NULL, NULL, 0, NULL}
