@@ -101,9 +101,11 @@ enum {
 typedef struct ezfill_s {
 	const char *cmd;
 	const char *var;
-	const float scale;  /*  if 0, no conversion is done and the string
-	                        is passed to dstate as is, otherwise a float
-	                        conversion with single decimal is applied */
+
+	/* if scale is 0, no conversion is done and the
+	 * string is passed to dstate as is; otherwise a
+	 * float conversion with single decimal is applied */
+	const float scale;
 } ezfill_t;
 
 /* These can be polled right into a string usable by NUT.
@@ -424,8 +426,9 @@ void upsdrv_initinfo(void)
 	dstate_addcmd("test.failure.start");
 	dstate_addcmd("load.off");
 	dstate_addcmd("load.on");
-	if( optimodel != OPTIMODEL_ZINTO )
-	dstate_addcmd("shutdown.stop");
+	if (optimodel != OPTIMODEL_ZINTO) {
+		dstate_addcmd("shutdown.stop");
+	}
 	dstate_addcmd("shutdown.return");
 	dstate_addcmd("shutdown.stayoff");
 	upsh.instcmd = instcmd;
