@@ -66,6 +66,7 @@
 
    The following parameters (ups.conf) are supported:
 	lowbatt
+	command_delay
 
    The following variables are supported (RW = read/write):
 	ambient.humidity (1)
@@ -126,7 +127,7 @@
 #include "nut_stdint.h"
 
 #define DRIVER_NAME	"Tripp Lite SmartOnline driver"
-#define DRIVER_VERSION	"0.11"
+#define DRIVER_VERSION	"0.12"
 
 /* driver description structure */
 upsdrv_info_t upsdrv_info = {
@@ -163,6 +164,8 @@ static struct {
 	unsigned long commands_available;
 } ups;
 
+static long command_delay = 0; /* delay in milliseconds before each command, 0 = no delay by default */
+
 /* bits in commands_available */
 #define WDG_AVAILABLE            (1UL <<  1)
 
@@ -224,6 +227,11 @@ static ssize_t do_command(char type, const char *command, const char *parameters
 
 	ser_flush_io(upsfd);
 
+	/* Apply configurable delay if enabled (> 0) to prevent communication timeouts */
+	if (command_delay > 0) {
+		usleep((useconds_t)command_delay*1000);
+	}
+
 	if (response) {
 		*response = '\0';
 	}
@@ -302,9 +310,9 @@ static ssize_t do_command(char type, const char *command, const char *parameters
 		upsdebugx(3, "do_command: %" PRIiSIZE " bytes read [%s]", ret, response);
 
 		/* Tripp Lite pads their string responses with spaces.
-		   I don't like that, so I remove them.  This is safe to
-		   do with all responses for this protocol, so I just
-		   do that here. */
+		 * I don't like that, so I remove them.  This is safe to
+		 * do with all responses for this protocol, so I just
+		 * do that here. */
 		str_rtrim(response, ' ');
 
 		return ret;
@@ -786,9 +794,13 @@ void upsdrv_updateinfo(void)
 	if (ptr) {
 		dstate_setinfo("battery.charge", "%d", atoi(ptr));
 		ptr2 = getval("lowbatt");
-		if (ptr2 && atoi(ptr2) > 0 && atoi(ptr2) <= 99 &&
-		    atoi(ptr) <= atoi(ptr2))
+		if (ptr2
+		 && atoi(ptr2) > 0
+		 && atoi(ptr2) <= 99
+		 && atoi(ptr) <= atoi(ptr2)
+		) {
 			low_battery = 1;
+		}
 	}
 	ptr = field(response, 6);
 	if (ptr)
@@ -870,7 +882,7 @@ void upsdrv_shutdown(void)
 		printf("Status failed.  Assuming it's on battery and trying a shutdown anyway.\n");
 	auto_reboot(1);
 	/* in case the power is on, tell it to automatically reboot.  if
-	   it is off, this has no effect. */
+	 * it is off, this has no effect. */
 	snprintf(parm, sizeof(parm), "%d", 1); /* delay before reboot, in minutes */
 	do_command(SET, TSU_SHUTDOWN_RESTART, parm, NULL);
 	snprintf(parm, sizeof(parm), "%d", 5); /* delay before shutdown, in seconds */
@@ -890,12 +902,35 @@ void upsdrv_tweak_prognames(void)
 void upsdrv_makevartable(void)
 {
 	addvar(VAR_VALUE, "lowbatt", "Set low battery level, in percent");
+	addvar(VAR_VALUE, "command_delay", 
+		"Delay in milliseconds before each command (default: 0 = no delay; "
+		"set to 1000ms if experiencing communication timeouts)");
 }
 
 void upsdrv_initups(void)
 {
+	const char *val;
+
 	upsfd = ser_open(device_path);
 	ser_set_speed(upsfd, device_path, B2400);
+
+	/* Initialize command_delay from configuration */
+	val = getval("command_delay");
+	if (val) {
+		long temp = atol(val);
+		/* 0 (no delay) or positive values */
+		if (temp < 0) {
+			fatalx(EXIT_FAILURE, "Invalid command_delay parameter: %s (must be >= 0)", val);
+		}
+		command_delay = temp;
+		if (command_delay == 0) {
+			upsdebugx(2, "command_delay is explicitly set to 0 (no delay)");
+		} else {
+			upsdebugx(2, "Setting command_delay to %ld milliseconds", command_delay);
+		}
+	} else {
+		upsdebugx(2, "Using default command_delay of %ld (no delay)", command_delay);
+	}
 }
 
 void upsdrv_cleanup(void)
