@@ -42,11 +42,19 @@ void upsdrvquery_close(udq_pipe_conn_t *conn);
 ssize_t upsdrvquery_read_timeout(udq_pipe_conn_t *conn, struct timeval tv);
 ssize_t upsdrvquery_write(udq_pipe_conn_t *conn, const char *buf);
 
+/* Return 1 if we had a reply within timeout specified by *ptv (5 sec if NULL),
+ * 0 if not, -1 on socket errors */
+ssize_t upsdrvquery_ping(udq_pipe_conn_t *conn, struct timeval *ptv, useconds_t read_interval);
 ssize_t upsdrvquery_prepare(udq_pipe_conn_t *conn, struct timeval tv);
 ssize_t upsdrvquery_request(udq_pipe_conn_t *conn, struct timeval tv, const char *query);
+ssize_t upsdrvquery_restore_broadcast(udq_pipe_conn_t *conn);
 
 /* if buf != NULL, last reply is copied there */
 ssize_t upsdrvquery_oneshot(const char *drvname, const char *upsname, const char *query, char *buf, const size_t bufsz, struct timeval *tv);
+ssize_t upsdrvquery_oneshot_sockfn(const char *sockfn, const char *query, char *buf, const size_t bufsz, struct timeval *tv);
+
+/* One-shot using an existing connection (caller must close + free connection) */
+ssize_t upsdrvquery_oneshot_conn(udq_pipe_conn_t *conn, const char *query, char *buf, const size_t bufsz, struct timeval *tv);
 
 /* Internal toggle for some NUT programs that deal with Unix socket chatter.
  * For a detailed rationale comment see upsdrvquery.c */
@@ -55,4 +63,12 @@ extern int nut_upsdrvquery_debug_level;
 #define NUT_UPSDRVQUERY_DEBUG_LEVEL_CONNECT	5
 #define NUT_UPSDRVQUERY_DEBUG_LEVEL_DIALOG	4
 
+/* Do our best to disable SIGPIPE in failed write()/send() attempts?
+ * Note errno=EPIPE should still be raised in case of failure, just
+ * the process using this code would not crash. Feature is enabled
+ * by default, but consumers which handle their signals specially
+ * can disable it by setting upsdrvquery_NOSIGPIPE=0
+ */
+extern int upsdrvquery_NOSIGPIPE;
+
 #endif	/* NUT_UPSDRVQUERY_H_SEEN */
