@@ -32,11 +32,15 @@ extern "C" {
 
 #define ST_SOCK_BUF_LEN 512
 
+#include "timehead.h"
+
 #if defined(HAVE_CLOCK_GETTIME) && defined(HAVE_CLOCK_MONOTONIC) && HAVE_CLOCK_GETTIME && HAVE_CLOCK_MONOTONIC
 typedef struct timespec	st_tree_timespec_t;
 #else
 typedef struct timeval	st_tree_timespec_t;
 #endif
+/* Absorb the build-time variation */
+double difftime_st_tree_timespec(st_tree_timespec_t finish, st_tree_timespec_t start);
 
 typedef struct st_tree_s {
 	char	*var;
