@@ -76,7 +76,7 @@ static void ups_create(const char *fn, const char *name, const char *desc)
 			name);
 		return;
 	}
-#endif
+#endif	/* WIN32 */
 	temp->sock_fd = sstate_connect(temp);
 
 	/* preload this to the current time to avoid false staleness */
@@ -119,9 +119,9 @@ static void ups_update(const char *fn, const char *name, const char *desc)
 
 #ifndef WIN32
 		close(temp->sock_fd);
-#else
+#else	/* WIN32 */
 		CloseHandle(temp->sock_fd);
-#endif
+#endif	/* WIN32 */
 		temp->sock_fd = ERROR_FD;
 		temp->dumpdone = 0;
 
@@ -169,7 +169,7 @@ static int parse_upsd_conf_args(size_t numargs, char **arg)
 	/* DEBUG_MIN (NUM) */
 	/* debug_min (NUM) also acceptable, to be on par with ups.conf */
 	if (!strcasecmp(arg[0], "DEBUG_MIN")) {
-		int lvl = -1; // typeof common/common.c: int nut_debug_level
+		int lvl = -1; /* typeof common/common.c: int nut_debug_level */
 		if ( str_to_int (arg[1], &lvl, 10) && lvl >= 0 ) {
 			nut_debug_level_global = lvl;
 		} else {
@@ -202,7 +202,7 @@ static int parse_upsd_conf_args(size_t numargs, char **arg)
 		}
 	}
 
-	/* ALLOW_NO_DEVICE <seconds> */
+	/* ALLOW_NO_DEVICE <bool> */
 	if (!strcmp(arg[0], "ALLOW_NO_DEVICE")) {
 		if (isdigit((size_t)arg[1][0])) {
 			allow_no_device = (atoi(arg[1]) != 0); /* non-zero arg is true here */
@@ -215,6 +215,19 @@ static int parse_upsd_conf_args(size_t numargs, char **arg)
 		return 0;
 	}
 
+	/* ALLOW_NOT_ALL_LISTENERS <bool> */
+	if (!strcmp(arg[0], "ALLOW_NOT_ALL_LISTENERS")) {
+		if (isdigit((size_t)arg[1][0])) {
+			allow_not_all_listeners = (atoi(arg[1]) != 0); /* non-zero arg is true here */
+			return 1;
+		}
+		if (parse_boolean(arg[1], &allow_not_all_listeners))
+			return 1;
+
+		upslogx(LOG_ERR, "ALLOW_NOT_ALL_LISTENERS has non numeric and non boolean value (%s)!", arg[1]);
+		return 0;
+	}
+
 	/* MAXCONN <connections> */
 	if (!strcmp(arg[0], "MAXCONN")) {
 		if (isdigit((size_t)arg[1][0])) {
@@ -234,7 +247,7 @@ static int parse_upsd_conf_args(size_t numargs, char **arg)
 		if (sp && strcmp(sp, arg[1])) {
 			/* Only warn if the two strings are not equal */
 			upslogx(LOG_WARNING,
-				"Ignoring STATEPATH='%s' from configuration file, "
+				"Ignoring STATEPATH='%s' from upsd.conf configuration file, "
 				"in favor of NUT_STATEPATH='%s' environment variable",
 				NUT_STRARG(arg[1]), NUT_STRARG(sp));
 		}
@@ -305,7 +318,7 @@ static int parse_upsd_conf_args(size_t numargs, char **arg)
 	/* LISTEN <address> [<port>] */
 	if (!strcmp(arg[0], "LISTEN")) {
 		if (numargs < 3)
-			listen_add(arg[1], string_const(PORT));
+			listen_add(arg[1], string_const(NUT_PORT));
 		else
 			listen_add(arg[1], arg[2]);
 		return 1;
@@ -344,8 +357,9 @@ static void upsd_conf_err(const char *errmsg)
 
 void load_upsdconf(int reloading)
 {
-	char	fn[SMALLBUF];
+	char	fn[NUT_PATH_MAX];
 	PCONF_CTX_t	ctx;
+	int	numerrors = 0;
 
 	snprintf(fn, sizeof(fn), "%s/upsd.conf", confpath());
 
@@ -374,6 +388,7 @@ void load_upsdconf(int reloading)
 		if (pconf_parse_error(&ctx)) {
 			upslogx(LOG_ERR, "Parse error: %s:%d: %s",
 				fn, ctx.linenum, ctx.errmsg);
+			numerrors++;
 			continue;
 		}
 
@@ -391,6 +406,7 @@ void load_upsdconf(int reloading)
 				snprintfcat(errmsg, sizeof(errmsg), " %s",
 					ctx.arglist[i]);
 
+			numerrors++;
 			upslogx(LOG_WARNING, "%s", errmsg);
 		}
 
@@ -399,7 +415,7 @@ void load_upsdconf(int reloading)
 	if (reloading) {
 		if (nut_debug_level_global > -1) {
 			upslogx(LOG_INFO,
-				"Applying debug_min=%d from upsd.conf",
+				"Applying DEBUG_MIN %d from upsd.conf",
 				nut_debug_level_global);
 			nut_debug_level = nut_debug_level_global;
 		} else {
@@ -412,6 +428,13 @@ void load_upsdconf(int reloading)
 		}
 	}
 
+	/* FIXME: Per legacy behavior, we silently went on.
+	 * Maybe should abort on unusable configs?
+	 */
+	if (numerrors) {
+		upslogx(LOG_ERR, "Encountered %d config errors, those entries were ignored", numerrors);
+	}
+
 	pconf_finish(&ctx);
 }
 
@@ -420,8 +443,26 @@ void do_upsconf_args(char *upsname, char *var, char *val)
 {
 	ups_t	*temp;
 
-	/* no "global" stuff for us */
+	/* almost no "global" stuff for us */
 	if (!upsname) {
+
+		/* STATEPATH <dir> (may be lower-case) */
+		if (!strcasecmp(var, "STATEPATH")) {
+			const char *sp = getenv("NUT_STATEPATH");
+			if (sp && strcmp(sp, val)) {
+				/* Only warn if the two strings are not equal */
+				upslogx(LOG_WARNING,
+					"Ignoring STATEPATH='%s' from ups.conf configuration file, "
+					"in favor of NUT_STATEPATH='%s' environment variable",
+					NUT_STRARG(val), NUT_STRARG(sp));
+			}
+			free(statepath);
+			statepath = xstrdup(sp ? sp : val);
+			/* This setting source keeps priority
+			 * to best match up with the drivers */
+			setenv("NUT_STATEPATH", statepath, 1);
+		}
+
 		return;
 	}
 
@@ -456,7 +497,7 @@ void do_upsconf_args(char *upsname, char *var, char *val)
 void upsconf_add(int reloading)
 {
 	ups_t	*tmp = upstable, *next;
-	char	statefn[SMALLBUF];
+	char	statefn[NUT_PATH_MAX];
 
 	if (!tmp) {
 		upslogx(LOG_WARNING, "Warning: no UPS definitions in ups.conf");
@@ -530,9 +571,9 @@ static void delete_ups(upstype_t *target)
 			if (VALID_FD(ptr->sock_fd))
 #ifndef WIN32
 				close(ptr->sock_fd);
-#else
+#else	/* WIN32 */
 				CloseHandle(ptr->sock_fd);
-#endif
+#endif	/* WIN32 */
 
 			/* release memory */
 			sstate_infofree(ptr);
@@ -558,7 +599,7 @@ static void delete_ups(upstype_t *target)
 /* see if we can open a file */
 static int check_file(const char *fn)
 {
-	char	chkfn[SMALLBUF];
+	char	chkfn[NUT_PATH_MAX];
 	FILE	*f;
 
 	snprintf(chkfn, sizeof(chkfn), "%s/%s", confpath(), fn);
