@@ -31,6 +31,13 @@
 # Common sandbox run for testing goes from NUT root build directory like:
 #	DEBUG_SLEEP=600 NUT_PORT=12345 NIT_CASE=testcase_sandbox_start_drivers_after_upsd NUT_FOREGROUND_WITH_PID=true make check-NIT &
 #
+# NOTE: For systems where executables need an extension, like Windows,
+# you may require an EXEEXT variable to be exported (e.g. by a Makefile);
+# also on Windows the DLL shared libraries may have to be present in same
+# directory as the executable "module" (or in the current working directory).
+# Ability to run in cross-builds (e.g. NUT for Windows on Linux) may depend
+# on binary support deployed in the run-time system ( Wine, WSL... on Linux).
+#
 # Design note: written with dumbed-down POSIX shell syntax, to
 # properly work in whatever different OSes have (bash, dash,
 # ksh, busybox sh...)
@@ -159,8 +166,8 @@ isBusy_NUT_PORT() {
         # IPv6:
         #   sl  local_address                         remote_address                        st tx_queue rx_queue tr tm->when retrnsmt   uid  timeout inode
         #   0: 00000000000000000000000000000000:1F46 00000000000000000000000000000000:0000 0A 00000000:00000000 00:00000000 00000000    33        0 37451 1 00000000fa3c0c15 100 0 0 10 0
-        NUT_PORT_HEX="`printf '%04X' "${NUT_PORT}"`"
-        NUT_PORT_HITS="`cat /proc/net/tcp /proc/net/tcp6 2>/dev/null | awk '{print $2}' | ${EGREP} ":${NUT_PORT_HEX}\$"`" \
+        NUT_PORT_HEX="`printf '%04X' \"${NUT_PORT}\"`"
+        NUT_PORT_HITS="`cat /proc/net/tcp /proc/net/tcp6 2>/dev/null | awk '{print $2}' | ${EGREP} \":${NUT_PORT_HEX}\$\"`" \
         && [ -n "$NUT_PORT_HITS" ] \
         && log_debug "isBusy_NUT_PORT() found that NUT_PORT=${NUT_PORT} is busy per /proc/net/tcp*" \
         && return 0
@@ -219,6 +226,53 @@ die() {
 # By default, keep stdout hidden but report the errors:
 [ -n "$RUNCMD_QUIET_OUT" ] || RUNCMD_QUIET_OUT=true
 [ -n "$RUNCMD_QUIET_ERR" ] || RUNCMD_QUIET_ERR=false
+execcmd() {
+    # Help set up EXEEXT and logging, but allow use for backgrounded runs.
+    # WARNING: uses `exec` and overrides NUT_DEBUG_LEVEL, so must be
+    # called as sub-shelled (by pipe, amperesand, backticks, etc.)!
+    # Do not "fix" this method to round parentheses, because the way
+    # this is works just right for remembering CHILDPID="$!" and later
+    # killing off the daemons.
+    log_debug "execcmd: asked for: $@"
+    CMDPROG=""
+    case "$1" in
+        upsc|*/upsc|upsc"${EXEEXT-}"|*/upsc"${EXEEXT-}")
+            if [ -n "${NUT_DEBUG_LEVEL_UPSC-}" ]; then
+                NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_UPSC}"
+            fi
+            ;;
+        nut-scanner|*/nut-scanner|nut-scanner"${EXEEXT-}"|*/nut-scanner"${EXEEXT-}")
+            if [ -n "${NUT_DEBUG_LEVEL_NUT_SCANNER-}" ]; then
+                NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_NUT_SCANNER}"
+            fi
+            ;;
+    esac
+
+    case "$1" in
+        *"${EXEEXT-}") CMDPROG="$1" ;;
+        *)  if [ -x "$1" ] || (command -v "$1") >/dev/null 2>/dev/null ; then
+                CMDPROG="$1"
+            else
+                if [ x"${EXEEXT-}" = x ] ; then
+                    log_warn "Did not find '$1' via 'command -v', the call below may fail"
+                    CMDPROG="$1"
+                else
+                    if [ -x "$1${EXEEXT-}" ] || (command -v "$1${EXEEXT-}") >/dev/null 2>/dev/null ; then
+                        CMDPROG="$1${EXEEXT}"
+                    else
+                        log_warn "Did not find '$1' nor '$1${EXEEXT-}' via 'command -v', the call below may fail"
+                        CMDPROG="$1"
+                    fi
+                fi
+            fi
+            ;;
+    esac
+    shift
+
+    log_debug "execcmd: running:   ${CMDPROG} $@"
+    exec "${CMDPROG}" "$@"
+}
+
 runcmd() {
     # Re-uses a couple of files in test scratch area NUT_STATEPATH
     # to store the stderr and stdout of the launched program.
@@ -232,24 +286,10 @@ runcmd() {
     CMDOUT=""
     CMDERR=""
 
-    # FIXME: Consider EXEEXT?
-    case "$0" in
-        upsc|*/upsc)
-            if [ -n "${NUT_DEBUG_LEVEL_UPSC-}" ]; then
-                NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_UPSC}"
-            fi
-            ;;
-        nut-scanner|*/nut-scanner)
-            if [ -n "${NUT_DEBUG_LEVEL_NUT_SCANNER-}" ]; then
-                NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_NUT_SCANNER}"
-            fi
-            ;;
-    esac
-
-    "$@" > "${NUT_STATEPATH}/runcmd.out" 2>"${NUT_STATEPATH}/runcmd.err" || CMDRES=$?
+    (execcmd "$@" > "${NUT_STATEPATH}/runcmd.out" 2>"${NUT_STATEPATH}/runcmd.err") || CMDRES=$?
     NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_ORIG}"
-    CMDOUT="`cat "${NUT_STATEPATH}/runcmd.out"`"
-    CMDERR="`cat "${NUT_STATEPATH}/runcmd.err"`"
+    CMDOUT="`cat \"${NUT_STATEPATH}/runcmd.out\"`"
+    CMDERR="`cat \"${NUT_STATEPATH}/runcmd.err\"`"
 
     [ "$RUNCMD_QUIET_OUT" = true ] || { [ -z "$CMDOUT" ] || echo "$CMDOUT" ; }
     [ "$RUNCMD_QUIET_ERR" = true ] || { [ -z "$CMDERR" ] || echo "$CMDERR" >&2 ; }
@@ -262,25 +302,89 @@ runcmd() {
 # from the source codebase are where the script resides, e.g.
 # the $(srcdir) from the Makefile. If we are not in the source
 # tree, tests would use binaries in PATH (e.g. packaged install).
-BUILDDIR="`pwd`"
+# Note that assumptions about relative paths below may NOT FIT
+# out-of-tree builds, like NUT for Windows under Linux, so we'd
+# better trust envvars from `make`, if exported and available to us!
+BUILDDIR=""
+log_debug "Current working directory: '`pwd`'"
+if [ x"${abs_builddir-}" != x ] ; then
+    BUILDDIR="${abs_builddir-}"
+    log_debug "Trying BUILDDIR='${BUILDDIR}' from make vars"
+else
+    if [ x"${builddir-}" != x ] ; then
+        log_debug "Trying BUILDDIR='${builddir}' from make vars"
+        BUILDDIR="`cd \"${builddir}\" && pwd`"
+    fi
+fi
+if [ x"${BUILDDIR}" = x ] || [ ! -d "${BUILDDIR}" ] ; then
+    BUILDDIR="`pwd`"
+    log_info "Guessing BUILDDIR='${BUILDDIR}' from script location..."
+else
+    log_info "Using BUILDDIR='${BUILDDIR}' from make vars"
+fi
+
 TOP_BUILDDIR=""
-case "${BUILDDIR}" in
-    */tests/NIT)
-        TOP_BUILDDIR="`cd "${BUILDDIR}"/../.. && pwd`" ;;
-    *) log_info "Current directory '${BUILDDIR}' is not a .../tests/NIT" ;;
-esac
+if [ x"${abs_top_builddir-}" != x ] ; then
+    TOP_BUILDDIR="${abs_top_builddir}"
+    log_debug "Trying TOP_BUILDDIR='${TOP_BUILDDIR}' from make vars"
+else
+    if [ x"${top_builddir-}" != x ] ; then
+        log_debug "Trying TOP_BUILDDIR='${top_builddir}' from make vars"
+        TOP_BUILDDIR="`cd \"${top_builddir}\" && pwd`"
+    fi
+fi
+if [ x"${TOP_BUILDDIR}" = x ] || [ ! -d "${TOP_BUILDDIR}" ] ; then
+    case "${BUILDDIR}" in
+        */tests/NIT)
+            TOP_BUILDDIR="`cd \"${BUILDDIR}\"/../.. && pwd`" ;;
+        *) log_info "Current directory '${BUILDDIR}' is not a .../tests/NIT" ;;
+    esac
+    log_info "Guessing TOP_BUILDDIR='${TOP_BUILDDIR}' from script location and/or BUILDDIR value..."
+else
+    log_info "Using TOP_BUILDDIR='${TOP_BUILDDIR}' from make vars"
+fi
 if test ! -w "${BUILDDIR}" ; then
     log_error "BUILDDIR='${BUILDDIR}' is not writeable, tests may fail below"
 fi
 
-SRCDIR="`dirname "$0"`"
-SRCDIR="`cd "$SRCDIR" && pwd`"
+SRCDIR=""
+if [ x"${abs_srcdir-}" != x ] ; then
+    SRCDIR="${abs_srcdir}"
+    log_debug "Trying SRCDIR='${SRCDIR}' from make vars"
+else
+    if [ x"${srcdir-}" != x ] ; then
+        log_debug "Trying SRCDIR='${srcdir}' from make vars"
+        SRCDIR="`cd \"${srcdir}\" && pwd`"
+    fi
+fi
+if [ x"${SRCDIR}" = x ] || [ ! -d "${SRCDIR}" ] ; then
+    SRCDIR="`dirname \"$0\"`"
+    SRCDIR="`cd \"$SRCDIR\" && pwd`"
+    log_info "Guessing SRCDIR='${SRCDIR}' from script location..."
+else
+    log_info "Using SRCDIR='${SRCDIR}' from make vars"
+fi
+
 TOP_SRCDIR=""
-case "${SRCDIR}" in
-    */tests/NIT)
-        TOP_SRCDIR="`cd "${SRCDIR}"/../.. && pwd`" ;;
-    *) log_info "Script source directory '${SRCDIR}' is not a .../tests/NIT" ;;
-esac
+if [ x"${abs_top_srcdir-}" != x ] ; then
+    TOP_SRCDIR="${abs_top_srcdir}"
+    log_debug "Trying TOP_SRCDIR='${TOP_SRCDIR}' from make vars"
+else
+    if [ x"${top_srcdir-}" != x ] ; then
+        log_debug "Trying TOP_SRCDIR='${top_srcdir}' from make vars"
+        TOP_SRCDIR="`cd \"${top_srcdir}\" && pwd`"
+    fi
+fi
+if [ x"${TOP_SRCDIR}" = x ] || [ ! -d "${TOP_SRCDIR}" ] ; then
+    case "${SRCDIR}" in
+        */tests/NIT)
+            TOP_SRCDIR="`cd \"${SRCDIR}\"/../.. && pwd`" ;;
+        *) log_info "Script source directory '${SRCDIR}' is not a .../tests/NIT" ;;
+    esac
+    log_info "Guessing TOP_SRCDIR='${TOP_SRCDIR}' from script location and/or SRCDIR value..."
+else
+    log_info "Using TOP_SRCDIR='${TOP_SRCDIR}' from make vars"
+fi
 
 # Make these paths known to e.g. upsmon/upssched and handler scripts they call
 export BUILDDIR TOP_BUILDDIR SRCDIR TOP_SRCDIR
@@ -322,8 +426,9 @@ else
     LD_LIBRARY_PATH_CLIENT="${LD_LIBRARY_PATH_ORIG}"
 fi
 
+log_info "Locating NUT programs to test:"
 for PROG in upsd upsc dummy-ups upsmon upslog upssched ; do
-    (command -v ${PROG}) || die "Useless setup: ${PROG} not found in PATH: ${PATH}"
+    (command -v ${PROG}) || (command -v ${PROG}${EXEEXT-}) || die "Useless setup: ${PROG} not found in PATH: ${PATH}"
 done
 
 PID_UPSD=""
@@ -355,6 +460,7 @@ get_my_user_name() {
     # TOTHINK: Fallback to get "my current user": touch a file and see who owns it?
 
     # Non-numeric (empty) stdout; non-successful exit code
+    log_warn "Current user account name was not found"
     return 1
 }
 
@@ -363,7 +469,7 @@ get_user_id() {
         && [ "${_ID}" -ge 0 ] 2>/dev/null ; then echo "${_ID}"; return ; fi
     if _ID="`id ${1-} 2>/dev/null | sed -e 's,^.*uid=,,' -e 's,(.*$,,'`" \
         && [ "${_ID}" -ge 0 ] 2>/dev/null ; then echo "${_ID}"; return ; fi
-    if [ x"${1-}" != x ] 2>/dev/null && _ID="`getent passwd "$1" 2>/dev/null | awk -F: '{print $3}'`" \
+    if [ x"${1-}" != x ] 2>/dev/null && _ID="`getent passwd \"$1\" 2>/dev/null | awk -F: '{print $3}'`" \
         && [ "${_ID}" -ge 0 ] 2>/dev/null ; then echo "${_ID}"; return ; fi
 
     # Fallback
@@ -376,6 +482,7 @@ get_user_id() {
     fi
 
     # Non-numeric (empty) stdout; non-successful exit code
+    log_warn "User ID for name '${1-}' was not found"
     return 1
 }
 
@@ -384,12 +491,21 @@ get_group_id() {
         && [ "${_ID}" -ge 0 ] 2>/dev/null ; then echo "${_ID}"; return ; fi
     if _ID="`id ${1-} 2>/dev/null | sed -e 's,^.*gid=,,' -e 's,(.*$,,'`" \
         && [ "${_ID}" -ge 0 ] 2>/dev/null ; then echo "${_ID}"; return ; fi
-    if [ x"${1-}" != x ] 2>/dev/null && _ID="`getent group "$1" 2>/dev/null | awk -F: '{print $3}'`" \
+    if [ x"${1-}" != x ] 2>/dev/null && _ID="`getent group \"$1\" 2>/dev/null | awk -F: '{print $3}'`" \
         && [ "${_ID}" -ge 0 ] 2>/dev/null ; then echo "${_ID}"; return ; fi
 
     # TOTHINK: Fallback to get "my current group": touch a file and see who owns it?
 
     # Non-numeric (empty) stdout; non-successful exit code
+    case "`uname -a | tr 'A-Z' 'a-z'`" in
+        *mingw*|*msys*|*win*)
+            # Windows? Avoid "not a number" error messages,
+            # common Unix groups are unlikely here...
+            echo "-1"
+            ;;
+    esac
+
+    log_warn "Group ID for name '${1-}' was not found"
     return 1
 }
 
@@ -421,7 +537,7 @@ TWEAK_RUN_AS_USER=""
 TWEAK_RUN_AS_GROUP=""
 ARG_USER=""
 if [ x"${BUILTIN_RUN_AS_USER}" != x ] ; then
-    if [ "`get_user_id "${BUILTIN_RUN_AS_USER}"`" -ge 0 ] 2>/dev/null; then
+    if [ "`get_user_id \"${BUILTIN_RUN_AS_USER}\"`" -ge 0 ] 2>/dev/null; then
         # Do not bother to re-evaluate more IDs to rule out aliases - many names on same ID?
         if $I_AM_ROOT || [ x"${I_AM_NAME}" = x"${BUILTIN_RUN_AS_USER}" ] ; then
             log_info "Started as ${I_AM_NAME_REPORT}, and built-in RUN_AS_USER='${BUILTIN_RUN_AS_USER}' seems present on this system to run test daemons as"
@@ -433,7 +549,7 @@ if [ x"${BUILTIN_RUN_AS_USER}" != x ] ; then
         # account identification databases of this runtime environment...
         if $I_AM_ROOT ; then
             for U in nobody daemon bin ; do
-                if [ "`get_user_id "${U}"`" -ge 0 ] ; then
+                if [ "`get_user_id \"${U}\"`" -ge 0 ] ; then
                     TWEAK_RUN_AS_USER="${U}"
                     break
                 fi
@@ -457,7 +573,7 @@ if [ x"${BUILTIN_RUN_AS_GROUP}" != x ] ; then
     # * In `drivers/main.c` we can set FS access for the pipe to data server
     # * Otherwise in `common.c::become_user()` we try to assume the default
     #   GID of that user account we were asked to switch into.
-    if [ "`get_group_id "${BUILTIN_RUN_AS_GROUP}"`" -ge 0 ] 2>/dev/null ; then
+    if [ "`get_group_id \"${BUILTIN_RUN_AS_GROUP}\"`" -ge 0 ] 2>/dev/null ; then
         # Do not bother to re-evaluate more IDs to rule out aliases - many names on same ID?
         # TOTHINK: Would need I_AM_GROUP first?..
         if $I_AM_ROOT ; then
@@ -469,7 +585,7 @@ if [ x"${BUILTIN_RUN_AS_GROUP}" != x ] ; then
         # The string allegedly built into NUT binaries is unknown to the
         # account identification databases of this runtime environment...
         for G in nobody nogroup daemon bin ; do
-            if [ "`get_group_id "${G}"`" -ge 0 ] ; then
+            if [ "`get_group_id \"${G}\"`" -ge 0 ] ; then
                 TWEAK_RUN_AS_GROUP="${G}"
                 break
             fi
@@ -518,7 +634,7 @@ if [ x"${TESTDIR}" = x ] ; then
     fi
     log_warn "Will now mktemp a TESTDIR under '${TMPDIR}'. It will be wiped when the NIT script exits."
     log_warn "If you want a pre-determined location, pre-export a usable TESTDIR value."
-    TESTDIR="`mktemp -d "${TMPDIR}/nit-tmp.$$.XXXXXX"`" || die "Failed to mktemp"
+    TESTDIR="`mktemp -d \"${TMPDIR}/nit-tmp.$$.XXXXXX\"`" || die "Failed to mktemp"
     if $I_AM_ROOT ; then
         # Cah be protected as 0700 by default
         chmod ugo+rx "${TESTDIR}"
@@ -558,11 +674,11 @@ stop_daemons() {
     fi
 
     if [ -z "$PID_UPSSCHED" ] && [ -s "$NUT_PIDPATH/upssched.pid" ] ; then
-        PID_UPSSCHED="`head -1 "$NUT_PIDPATH/upssched.pid"`"
+        PID_UPSSCHED="`head -1 \"$NUT_PIDPATH/upssched.pid\"`"
     fi
 
     if [ -s "$NUT_PIDPATH/upssched.pid" ] ; then
-        PID_UPSSCHED_NOW="`head -1 "$NUT_PIDPATH/upssched.pid"`"
+        PID_UPSSCHED_NOW="`head -1 \"$NUT_PIDPATH/upssched.pid\"`"
     fi
 
     if [ -n "$PID_UPSD$PID_UPSMON$PID_DUMMYUPS$PID_DUMMYUPS1$PID_DUMMYUPS2$PID_UPSSCHED$PID_UPSSCHED_NOW" ] ; then
@@ -615,7 +731,7 @@ else
         fi
 
         log_warn "Selected NUT_PORT=$NUT_PORT seems occupied; will try another in a few seconds"
-        COUNTDOWN="`expr "$COUNTDOWN" - 1`"
+        COUNTDOWN="`expr \"$COUNTDOWN\" - 1`"
 
         [ "$COUNTDOWN" = 0 ] || sleep 2
     done
@@ -633,7 +749,7 @@ else
             fi
 
             # Loop quickly, no sleep here
-            COUNTDOWN="`expr "$COUNTDOWN" - 1`"
+            COUNTDOWN="`expr \"$COUNTDOWN\" - 1`"
         done
 
         if [ "$COUNTDOWN" = 0 ] ; then
@@ -975,7 +1091,7 @@ testcase_upsd_no_configs_at_all() {
     if [ -n "${NUT_DEBUG_LEVEL_UPSD-}" ]; then
         NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_UPSD}"
     fi
-    upsd ${ARG_FG} ${ARG_USER}
+    (execcmd upsd ${ARG_FG} ${ARG_USER})
     if [ "$?" = 0 ]; then
         log_error "[testcase_upsd_no_configs_at_all] upsd should fail without configs"
         FAILED="`expr $FAILED + 1`"
@@ -994,7 +1110,7 @@ testcase_upsd_no_configs_driver_file() {
     if [ -n "${NUT_DEBUG_LEVEL_UPSD-}" ]; then
         NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_UPSD}"
     fi
-    upsd ${ARG_FG} ${ARG_USER}
+    (execcmd upsd ${ARG_FG} ${ARG_USER})
     if [ "$?" = 0 ]; then
         log_error "[testcase_upsd_no_configs_driver_file] upsd should fail without driver config file"
         FAILED="`expr $FAILED + 1`"
@@ -1014,7 +1130,7 @@ testcase_upsd_no_configs_in_driver_file() {
     if [ -n "${NUT_DEBUG_LEVEL_UPSD-}" ]; then
         NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_UPSD}"
     fi
-    upsd ${ARG_FG} ${ARG_USER}
+    (execcmd upsd ${ARG_FG} ${ARG_USER})
     if [ "$?" = 0 ]; then
         log_error "[testcase_upsd_no_configs_in_driver_file] upsd should fail without drivers defined in config file"
         FAILED="`expr $FAILED + 1`"
@@ -1036,7 +1152,7 @@ upsd_start_loop() {
     if [ -n "${NUT_DEBUG_LEVEL_UPSD-}" ]; then
         NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_UPSD}"
     fi
-    upsd ${ARG_FG} ${ARG_USER} &
+    execcmd upsd ${ARG_FG} ${ARG_USER} &
     PID_UPSD="$!"
     NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_ORIG}"
     log_debug "[${TESTCASE}] Tried to start UPSD as PID $PID_UPSD"
@@ -1070,7 +1186,7 @@ upsd_start_loop() {
         if [ -n "${NUT_DEBUG_LEVEL_UPSD-}" ]; then
             NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_UPSD}"
         fi
-        upsd ${ARG_FG} ${ARG_USER} &
+        execcmd upsd ${ARG_FG} ${ARG_USER} &
         PID_UPSD="$!"
         NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_ORIG}"
         log_warn "[${TESTCASE}] Tried to start UPSD again, now as PID $PID_UPSD"
@@ -1138,6 +1254,28 @@ testcase_upsd_allow_no_device() {
             log_info "[testcase_upsd_allow_no_device] OK, empty response as expected"
             PASSED="`expr $PASSED + 1`"
         fi
+
+        log_separator
+        log_info "[testcase_upsd_allow_no_device] Query JSON listing from UPSD by UPSC (no devices configured yet) to test that UPSD responds to UPSC"
+        if runcmd upsc -j -l localhost:$NUT_PORT && test x"${CMDOUT}" != x ; then
+            log_debug "[testcase_upsd_allow_no_device] got a JSON reply:" "$CMDOUT"
+            JSTRIP="`echo \"${CMDOUT}\" | tr -d ' ' | tr -d '\n' | tr -d '\r'`"
+            if test x"${JSTRIP}" = x'[]' ; then
+                log_info "[testcase_upsd_allow_no_device] OK, empty-list JSON response as expected"
+                PASSED="`expr $PASSED + 1`"
+            else
+                log_error "[testcase_upsd_allow_no_device] got a reply for upsc JSON listing for empty but running server, but it was not expected (not an empty list):" "$CMDOUT" "$CMDERR"
+                FAILED="`expr $FAILED + 1`"
+                FAILED_FUNCS="$FAILED_FUNCS testcase_upsd_allow_no_device"
+                res_testcase_upsd_allow_no_device=1
+            fi
+        else
+            log_error "[testcase_upsd_allow_no_device] did not get a reply for upsc JSON listing for empty but running server:" "$CMDOUT" "$CMDERR"
+            FAILED="`expr $FAILED + 1`"
+            FAILED_FUNCS="$FAILED_FUNCS testcase_upsd_allow_no_device"
+            res_testcase_upsd_allow_no_device=1
+        fi
+        log_separator
     else
         log_error "[testcase_upsd_allow_no_device] upsd was expected to be running although no devices are defined; is ups.conf populated?"
         ls -la "$NUT_CONFPATH/" || true
@@ -1221,17 +1359,17 @@ sandbox_start_drivers() {
     if [ -n "${NUT_DEBUG_LEVEL_DRIVERS-}" ]; then
         NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_DRIVERS}"
     fi
-    #upsdrvctl ${ARG_FG} ${ARG_USER} start dummy &
-    dummy-ups -a dummy ${ARG_USER} ${ARG_FG} &
+    #execcmd upsdrvctl ${ARG_FG} ${ARG_USER} start dummy &
+    execcmd dummy-ups -a dummy ${ARG_USER} ${ARG_FG} &
     PID_DUMMYUPS="$!"
     log_debug "Tried to start dummy-ups driver for 'dummy' as PID $PID_DUMMYUPS"
 
     if [ x"${TOP_SRCDIR}" != x ]; then
-        dummy-ups -a UPS1 ${ARG_USER} ${ARG_FG} &
+        execcmd dummy-ups -a UPS1 ${ARG_USER} ${ARG_FG} &
         PID_DUMMYUPS1="$!"
         log_debug "Tried to start dummy-ups driver for 'UPS1' as PID $PID_DUMMYUPS1"
 
-        dummy-ups -a UPS2 ${ARG_USER} ${ARG_FG} &
+        execcmd dummy-ups -a UPS2 ${ARG_USER} ${ARG_FG} &
         PID_DUMMYUPS2="$!"
         log_debug "Tried to start dummy-ups driver for 'UPS2' as PID $PID_DUMMYUPS2"
     fi
@@ -1240,7 +1378,7 @@ sandbox_start_drivers() {
     sleep 5
 
     if shouldDebug ; then
-        (ps -ef || ps -xawwu) 2>/dev/null | ${EGREP} '(ups|nut|dummy|'"`basename "$0"`"')' | ${EGREP} -v '(ssh|startups|grep)' || true
+        (ps -ef || ps -xawwu) 2>/dev/null | ${EGREP} '(ups|nut|dummy|'"`basename \"$0\"`"')' | ${EGREP} -v '(ssh|startups|grep)' || true
     fi
 
     if isPidAlive "$PID_DUMMYUPS" \
@@ -1267,15 +1405,27 @@ testcase_sandbox_start_upsd_alone() {
 UPS1
 UPS2"
         # For windows runners (strip CR if any):
-        EXPECTED_UPSLIST="`echo "$EXPECTED_UPSLIST" | tr -d '\r'`"
+        EXPECTED_UPSLIST="`echo \"$EXPECTED_UPSLIST\" | tr -d '\r'`"
     fi
 
+    EXPECTED_UPSLIST_JSON='[
+  "dummy"'
+    if [ x"${TOP_SRCDIR}" != x ]; then
+        EXPECTED_UPSLIST_JSON="${EXPECTED_UPSLIST_JSON},"'
+  "UPS1",
+  "UPS2"'
+    fi
+    EXPECTED_UPSLIST_JSON="${EXPECTED_UPSLIST_JSON}"'
+]'
+    # For windows runners (strip CR if any):
+    EXPECTED_UPSLIST_JSON="`echo \"$EXPECTED_UPSLIST_JSON\" | tr -d '\r'`"
+
     log_info "[testcase_sandbox_start_upsd_alone] Query listing from UPSD by UPSC (driver not running yet)"
     res_testcase_sandbox_start_upsd_alone=0
     runcmd upsc -l localhost:$NUT_PORT || die "[testcase_sandbox_start_upsd_alone] upsd does not respond on port ${NUT_PORT} ($?): $CMDOUT"
     # For windows runners (printf can do wonders, so strip CR if any):
     if [ x"${TOP_SRCDIR}" != x ]; then
-        CMDOUT="`echo "$CMDOUT" | tr -d '\r'`"
+        CMDOUT="`echo \"$CMDOUT\" | tr -d '\r'`"
     fi
     if [ x"$CMDOUT" != x"$EXPECTED_UPSLIST" ] ; then
         log_error "[testcase_sandbox_start_upsd_alone] got this reply for upsc listing when '$EXPECTED_UPSLIST' was expected: '$CMDOUT'"
@@ -1286,6 +1436,19 @@ UPS2"
         PASSED="`expr $PASSED + 1`"
     fi
 
+    runcmd upsc -j -l localhost:$NUT_PORT || die "[testcase_sandbox_start_upsd_alone] upsd does not respond on port ${NUT_PORT} or JSON listing failed ($?): $CMDOUT"
+    if [ x"${TOP_SRCDIR}" != x ]; then
+        CMDOUT="`echo \"$CMDOUT\" | tr -d '\r'`"
+    fi
+    if [ x"$CMDOUT" != x"$EXPECTED_UPSLIST_JSON" ] ; then
+        log_error "[testcase_sandbox_start_upsd_alone] got this reply for upsc JSON listing when '$EXPECTED_UPSLIST' was expected: '$CMDOUT'"
+        FAILED="`expr $FAILED + 1`"
+        FAILED_FUNCS="$FAILED_FUNCS testcase_sandbox_start_upsd_alone"
+        res_testcase_sandbox_start_upsd_alone=1
+    else
+        PASSED="`expr $PASSED + 1`"
+    fi
+
     log_info "[testcase_sandbox_start_upsd_alone] Query driver state from UPSD by UPSC (driver not running yet)"
     runcmd upsc dummy@localhost:$NUT_PORT && {
         log_error "upsc was supposed to answer with error exit code: $CMDOUT"
@@ -1303,6 +1466,30 @@ UPS2"
         res_testcase_sandbox_start_upsd_alone=1
     fi
 
+    log_info "[testcase_sandbox_start_upsd_alone] Query driver state from UPSD by UPSC (driver not running yet) in JSON mode"
+    runcmd upsc -j dummy@localhost:$NUT_PORT && {
+        log_error "upsc was supposed to answer with error exit code: $CMDOUT"
+        FAILED="`expr $FAILED + 1`"
+        FAILED_FUNCS="$FAILED_FUNCS testcase_sandbox_start_upsd_alone"
+        res_testcase_sandbox_start_upsd_alone=1
+    }
+    log_debug "[testcase_sandbox_start_upsd_alone] got a JSON reply:" "$CMDOUT"
+    EXPECTED_UPSDATA_JSON='{
+  "error": "Driver not connected"
+}'
+    # For windows runners (strip CR if any):
+    EXPECTED_UPSDATA_JSON="`echo \"$EXPECTED_UPSDATA_JSON\" | tr -d '\r'`"
+    CMDOUT="`echo \"$CMDOUT\" | tr -d '\r'`"
+    # Note: avoid exact matching for stderr, because it can have Init SSL messages etc.
+    if echo "$CMDERR" | ${GREP} 'Error: Driver not connected' >/dev/null && test x"${CMDOUT}" = x"${EXPECTED_UPSDATA_JSON}"; then
+        PASSED="`expr $PASSED + 1`"
+    else
+        log_error "[testcase_sandbox_start_upsd_alone] got some other reply for upsc JSON query when 'Error: Driver not connected' was expected on stderr and similar in JSON object: '$CMDOUT'"
+        FAILED="`expr $FAILED + 1`"
+        FAILED_FUNCS="$FAILED_FUNCS testcase_sandbox_start_upsd_alone"
+        res_testcase_sandbox_start_upsd_alone=1
+    fi
+
     if [ "$res_testcase_sandbox_start_upsd_alone" = 0 ]; then
         log_info "[testcase_sandbox_start_upsd_alone] PASSED: got just the failures expected for data server alone (driver not running yet)"
     else
@@ -1312,6 +1499,17 @@ UPS2"
     return $res_testcase_sandbox_start_upsd_alone
 }
 
+EXPECTED_UPSWAIT_JSON='{
+  "ups.status": "WAIT"
+}'
+EXPECTED_UPSWAIT_JSON2='{
+  "driver.state": "updateinfo",
+  "ups.status": "WAIT"
+}'
+# For windows runners (strip CR if any):
+EXPECTED_UPSWAIT_JSON="`echo \"$EXPECTED_UPSDATA_JSON\" | tr -d '\r'`"
+EXPECTED_UPSWAIT_JSON2="`echo \"$EXPECTED_UPSDATA_JSON2\" | tr -d '\r'`"
+
 testcase_sandbox_start_upsd_after_drivers() {
     # Historically this is a fallback from testcase_sandbox_start_drivers_after_upsd
     log_info "[testcase_sandbox_start_upsd_after_drivers] Test starting UPSD after drivers"
@@ -1323,7 +1521,7 @@ testcase_sandbox_start_upsd_after_drivers() {
     if [ -n "${NUT_DEBUG_LEVEL_UPSD-}" ]; then
         NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_UPSD}"
     fi
-    upsd ${ARG_FG} ${ARG_USER} &
+    execcmd upsd ${ARG_FG} ${ARG_USER} &
     PID_UPSD="$!"
     NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_ORIG}"
     log_debug "[testcase_sandbox_start_upsd_after_drivers] Tried to start UPSD as PID $PID_UPSD"
@@ -1334,13 +1532,24 @@ testcase_sandbox_start_upsd_after_drivers() {
     sleep 5
 
     COUNTDOWN=90
+    GOT_REPLY=false
     while [ "$COUNTDOWN" -gt 0 ]; do
         # For query errors or known wait, keep looping
         runcmd upsc dummy@localhost:$NUT_PORT \
         && case "$CMDOUT" in
             *"ups.status: WAIT"*) ;;
-            *) log_info "Got output:" ; echo "$CMDOUT" ; break ;;
+            *) log_info "[testcase_sandbox_start_upsd_after_drivers] Got output:" ; echo "$CMDOUT" ; GOT_REPLY=true ;;
         esac
+
+        runcmd upsc -j dummy@localhost:$NUT_PORT \
+        && case "$CMDOUT" in
+            "${EXPECTED_UPSWAIT_JSON}") ;;
+            "${EXPECTED_UPSWAIT_JSON2}") ;;
+            *) log_info "[testcase_sandbox_start_upsd_after_drivers] Got JSON output:" ; echo "$CMDOUT" ; GOT_REPLY=true ;;
+        esac
+
+        if $GOT_REPLY ; then break ; fi
+
         sleep 1
         COUNTDOWN="`expr $COUNTDOWN - 1`"
     done
@@ -1369,6 +1578,7 @@ testcase_sandbox_start_drivers_after_upsd() {
     # 40+(drv)/50+(upsd) sec a DUMPALL is processed (regular 30-sec loop?) -
     # so tightly near a minute until we have sturdy replies.
     COUNTDOWN=90
+    GOT_REPLY=false
     while [ "$COUNTDOWN" -gt 0 ]; do
         # For query errors or known wait, keep looping. May get:
         #   driver.state: updateinfo
@@ -1376,8 +1586,18 @@ testcase_sandbox_start_drivers_after_upsd() {
         runcmd upsc dummy@localhost:$NUT_PORT \
         && case "$CMDOUT" in
             *"ups.status: WAIT"*) ;;
-            *) log_info "[testcase_sandbox_start_drivers_after_upsd] Got output:" ; echo "$CMDOUT" ; break ;;
+            *) log_info "[testcase_sandbox_start_drivers_after_upsd] Got output:" ; echo "$CMDOUT" ; GOT_REPLY=true ;;
         esac
+
+        runcmd upsc -j dummy@localhost:$NUT_PORT \
+        && case "$CMDOUT" in
+            "${EXPECTED_UPSWAIT_JSON}") ;;
+            "${EXPECTED_UPSWAIT_JSON2}") ;;
+            *) log_info "[testcase_sandbox_start_drivers_after_upsd] Got JSON output:" ; echo "$CMDOUT" ; GOT_REPLY=true ;;
+        esac
+
+        if $GOT_REPLY ; then break ; fi
+
         sleep 1
         COUNTDOWN="`expr $COUNTDOWN - 1`"
     done
@@ -1396,15 +1616,28 @@ testcase_sandbox_start_drivers_after_upsd() {
         log_info "[testcase_sandbox_start_drivers_after_upsd] Wait for dummy UPSes with larger data sets to initialize"
         for U in UPS1 UPS2 ; do
             COUNTDOWN=90
-            # TODO: Convert to runcmd()?
-            OUT=""
-            while [ x"$OUT" = x"ups.status: WAIT" ] ; do
-                OUT="`upsc $U@localhost:$NUT_PORT ups.status`" || break
-                [ x"$OUT" = x"ups.status: WAIT" ] || { log_info "[testcase_sandbox_start_drivers_after_upsd] Got output:"; echo "$OUT"; break; }
+            GOT_REPLY=false
+
+            while [ "$COUNTDOWN" -gt 0 ]; do
+                runcmd upsc $U@localhost:$NUT_PORT ups.status \
+                && case "$CMDOUT" in
+                    WAIT) ;;
+                    *) log_info "[testcase_sandbox_start_drivers_after_upsd] Got output for $U:" ; echo "$CMDOUT" ; GOT_REPLY=true ;;
+                esac
+
+                runcmd upsc -j $U@localhost:$NUT_PORT ups.status \
+                && case "$CMDOUT" in
+                    '"WAIT"') ;; # JSON string is a valid document too
+                    *) log_info "[testcase_sandbox_start_drivers_after_upsd] Got JSON output for $U:" ; echo "$CMDOUT" ; GOT_REPLY=true ;;
+                esac
+
+                if $GOT_REPLY ; then break ; fi
+
                 sleep 1
                 COUNTDOWN="`expr $COUNTDOWN - 1`"
+
                 # Systemic error, e.g. could not create socket file?
-                [ "$COUNTDOWN" -lt 1 ] && die "[testcase_sandbox_start_drivers_after_upsd] Dummy driver did not start or respond in time"
+                [ "$COUNTDOWN" -lt 1 ] && die "[testcase_sandbox_start_drivers_after_upsd] Dummy driver for $U did not start or respond in time"
             done
             if [ "$COUNTDOWN" -le 88 ] ; then
                 log_warn "[testcase_sandbox_start_drivers_after_upsd] Had to wait a few retries for the $U driver to connect"
@@ -1426,6 +1659,22 @@ testcase_sandbox_upsc_query_model() {
         PASSED="`expr $PASSED + 1`"
         log_info "[testcase_sandbox_upsc_query_model] PASSED: got expected model from dummy device: $CMDOUT"
     fi
+
+    log_info "[testcase_sandbox_upsc_query_model] Query model from dummy device in JSON"
+    runcmd upsc -j dummy@localhost:$NUT_PORT device.model || die "[testcase_sandbox_upsc_query_model] upsd does not respond on port ${NUT_PORT} or can not get JSON output ($?): $CMDOUT"
+    log_debug "[testcase_sandbox_upsc_query_model] got a JSON reply:" "$CMDOUT"
+    EXPECTED_UPSDATA_JSON='"Dummy UPS"'
+    # For windows runners (strip CR if any):
+    EXPECTED_UPSDATA_JSON="`echo \"$EXPECTED_UPSDATA_JSON\" | tr -d '\r'`"
+    CMDOUT="`echo \"$CMDOUT\" | tr -d '\r'`"
+    if [ x"$CMDOUT" != x"${EXPECTED_UPSDATA_JSON}" ] ; then
+        log_error "[testcase_sandbox_upsc_query_model] got this reply for upsc JSON query when 'device.model: Dummy UPS' was expected: $CMDOUT"
+        FAILED="`expr $FAILED + 1`"
+        FAILED_FUNCS="$FAILED_FUNCS testcase_sandbox_upsc_query_model"
+    else
+        PASSED="`expr $PASSED + 1`"
+        log_info "[testcase_sandbox_upsc_query_model] PASSED: got expected model from dummy device in JSON: $CMDOUT"
+    fi
 }
 
 testcase_sandbox_upsc_query_bogus() {
@@ -1444,6 +1693,31 @@ testcase_sandbox_upsc_query_bogus() {
         FAILED="`expr $FAILED + 1`"
         FAILED_FUNCS="$FAILED_FUNCS testcase_sandbox_upsc_query_bogus"
     fi
+
+    log_info "[testcase_sandbox_upsc_query_bogus] Query driver state from UPSD by UPSC for bogus info in JSON"
+    runcmd upsc -j dummy@localhost:$NUT_PORT ups.bogus.value && {
+        log_error "[testcase_sandbox_upsc_query_bogus] upsc was supposed to answer with error exit code: $CMDOUT"
+        FAILED="`expr $FAILED + 1`"
+        FAILED_FUNCS="$FAILED_FUNCS testcase_sandbox_upsc_query_bogus"
+    }
+    log_debug "[testcase_sandbox_upsc_query_bogus] got a JSON reply:" "$CMDOUT"
+    EXPECTED_UPSDATA_JSON='{"error": "Variable not supported by UPS"}'
+    EXPECTED_UPSDATA_JSON2='{
+  "error": "Variable not supported by UPS"
+}'
+    # For windows runners (strip CR if any):
+    EXPECTED_UPSDATA_JSON="`echo \"$EXPECTED_UPSDATA_JSON\" | tr -d '\r'`"
+    EXPECTED_UPSDATA_JSON2="`echo \"$EXPECTED_UPSDATA_JSON2\" | tr -d '\r'`"
+    CMDOUT="`echo \"$CMDOUT\" | tr -d '\r'`"
+    # Note: avoid exact matching for stderr, because it can have Init SSL messages etc.
+    if echo "$CMDERR" | ${GREP} 'Error: Variable not supported by UPS' >/dev/null && test x"${CMDOUT}" = x"${EXPECTED_UPSDATA_JSON}" -o x"${CMDOUT}" = x"${EXPECTED_UPSDATA_JSON2}" ; then
+        PASSED="`expr $PASSED + 1`"
+        log_info "[testcase_sandbox_upsc_query_bogus] PASSED: got expected reply to bogus query in JSON"
+    else
+        log_error "[testcase_sandbox_upsc_query_bogus] got some other reply for upsc JSON query when 'Error: Variable not supported by UPS' was expected on stderr: stderr:'$CMDERR' / stdout:'$CMDOUT'"
+        FAILED="`expr $FAILED + 1`"
+        FAILED_FUNCS="$FAILED_FUNCS testcase_sandbox_upsc_query_bogus"
+    fi
 }
 
 testcase_sandbox_upsc_query_timer() {
@@ -1460,13 +1734,13 @@ testcase_sandbox_upsc_query_timer() {
     if [ -n "${NUT_DEBUG_LEVEL_UPSLOG-}" ]; then
         NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_UPSLOG}"
     fi
-    upslog -F -i 1 -d 30 -m "dummy@localhost:${NUT_PORT},${NUT_STATEPATH}/upslog-dummy.log" &
+    execcmd upslog -F -i 1 -d 30 -m "dummy@localhost:${NUT_PORT},${NUT_STATEPATH}/upslog-dummy.log" &
     PID_UPSLOG="$!"
     NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_ORIG}"
 
     # TODO: Any need to convert to runcmd()?
-    OUT1="`upsc dummy@localhost:$NUT_PORT ups.status`" || die "[testcase_sandbox_upsc_query_timer] upsd does not respond on port ${NUT_PORT} ($?): $OUT1" ; sleep 3
-    OUT2="`upsc dummy@localhost:$NUT_PORT ups.status`" || die "[testcase_sandbox_upsc_query_timer] upsd does not respond on port ${NUT_PORT} ($?): $OUT2"
+    OUT1="`execcmd upsc dummy@localhost:$NUT_PORT ups.status`" || die "[testcase_sandbox_upsc_query_timer] upsd does not respond on port ${NUT_PORT} ($?): $OUT1" ; sleep 3
+    OUT2="`execcmd upsc dummy@localhost:$NUT_PORT ups.status`" || die "[testcase_sandbox_upsc_query_timer] upsd does not respond on port ${NUT_PORT} ($?): $OUT2"
     OUT3=""
     OUT4=""
     OUT5=""
@@ -1475,13 +1749,13 @@ testcase_sandbox_upsc_query_timer() {
     # (pollfreq) after reading the file before wrapping around
     if [ x"$OUT1" = x"$OUT2" ]; then
         sleep 3
-        OUT3="`upsc dummy@localhost:$NUT_PORT ups.status`" || die "[testcase_sandbox_upsc_query_timer] upsd does not respond on port ${NUT_PORT} ($?): $OUT3"
+        OUT3="`execcmd upsc dummy@localhost:$NUT_PORT ups.status`" || die "[testcase_sandbox_upsc_query_timer] upsd does not respond on port ${NUT_PORT} ($?): $OUT3"
         if [ x"$OUT2" = x"$OUT3" ]; then
             sleep 3
-            OUT4="`upsc dummy@localhost:$NUT_PORT ups.status`" || die "[testcase_sandbox_upsc_query_timer] upsd does not respond on port ${NUT_PORT} ($?): $OUT4"
+            OUT4="`execcmd upsc dummy@localhost:$NUT_PORT ups.status`" || die "[testcase_sandbox_upsc_query_timer] upsd does not respond on port ${NUT_PORT} ($?): $OUT4"
             if [ x"$OUT3" = x"$OUT4" ]; then
                 sleep 8
-                OUT5="`upsc dummy@localhost:$NUT_PORT ups.status`" || die "[testcase_sandbox_upsc_query_timer] upsd does not respond on port ${NUT_PORT} ($?): $OUT4"
+                OUT5="`execcmd upsc dummy@localhost:$NUT_PORT ups.status`" || die "[testcase_sandbox_upsc_query_timer] upsd does not respond on port ${NUT_PORT} ($?): $OUT4"
             fi
         fi
     fi
@@ -1533,7 +1807,7 @@ isTestablePython() {
         return 0
     fi
 
-    PY_SHEBANG="`head -1 "${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py"`"
+    PY_SHEBANG="`head -1 \"${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py\"`"
     PY_RES=3
     case x"${PY_SHEBANG}" in
         x"#!"/*|x"#!"?":\\"*|x"#!"?":/"*) PY_RES=0 ;; # Seems like a full path
@@ -1543,7 +1817,7 @@ isTestablePython() {
     esac
     if [ x"${PY_RES}" = x0 ] ; then
         log_debug "=======\nDetected python shebang: '${PY_SHEBANG}' (result=${PY_RES})"
-        PYTHON="`echo "${PY_SHEBANG}" | sed 's,^#!,,'`"
+        PYTHON="`echo \"${PY_SHEBANG}\" | sed 's,^#!,,'`"
     else
         log_error "[isTestablePython] Detected python shebang: '${PY_SHEBANG}' (result=${PY_RES})"
     fi
@@ -1807,7 +2081,7 @@ testcase_sandbox_nutscanner_list() {
         else
             PORTS_WANT=3
         fi
-        PORTS_SEEN="`echo "$CMDOUT" | ${EGREP} -c 'port *='`"
+        PORTS_SEEN="`echo \"$CMDOUT\" | ${EGREP} -c 'port *='`"
 
         if [ "$PORTS_WANT" != "$PORTS_SEEN" ]; then
             log_error "[testcase_sandbox_nutscanner_list] Too many 'port=' lines: want $PORTS_WANT != seen $PORTS_SEEN" >&2
@@ -1848,7 +2122,7 @@ upsmon_start_loop() {
         # but the sample script honours NUT_DEBUG_LEVEL_UPSSCHED if set
         NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_UPSMON}"
     fi
-    upsmon ${ARG_FG} ${ARG_USER} &
+    execcmd upsmon ${ARG_FG} ${ARG_USER} &
     PID_UPSMON="$!"
     NUT_DEBUG_LEVEL="${NUT_DEBUG_LEVEL_ORIG}"
     log_debug "[${TESTCASE}] Tried to start UPSMON as PID $PID_UPSMON"
@@ -1999,7 +2273,7 @@ if [ -n "${DEBUG_SLEEP-}" ] ; then
     fi
 
     if [ -z "$PID_UPSSCHED" ] && [ -s "$NUT_PIDPATH/upssched.pid" ] ; then
-        PID_UPSSCHED="`head -1 "$NUT_PIDPATH/upssched.pid"`"
+        PID_UPSSCHED="`head -1 \"$NUT_PIDPATH/upssched.pid\"`"
     fi
 
     log_separator
@@ -2007,7 +2281,7 @@ if [ -n "${DEBUG_SLEEP-}" ] ; then
     log_info "Populated environment variables for this run into a file so you can source them: . '$NUT_CONFPATH/NIT.env'"
     printf "PID_NIT_SCRIPT='%s'\nexport PID_NIT_SCRIPT\n" "$$" >> "$NUT_CONFPATH/NIT.env"
     set | ${EGREP} '^TESTPASS_|PID_[^ =]*='"'?[0-9][0-9]*'?$" | while IFS='=' read K V ; do
-        V="`echo "$V" | tr -d "'"`"
+        V="`echo \"$V\" | tr -d \"'\"`"
         # Dummy comment to reset syntax highlighting due to ' quote above
         if [ -n "$V" ] ; then
             printf "%s='%s'\nexport %s\n" "$K" "$V" "$K"
