@@ -6,7 +6,8 @@
    as opposed to nutclienttest.cpp which unit-tests the class API etc.
    in isolated-binary fashion.
 
-   Copyright (C) 2022  Jim Klimov <jimklimov@gmail.com>
+   Copyright (C)
+	2022-2025	Jim Klimov <jimklimov+nut@gmail.com>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,8 +26,13 @@
 
 #include "common.h"
 
-/* Current CPPUnit offends the honor of C++98 */
-#if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_EXIT_TIME_DESTRUCTORS || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_GLOBAL_CONSTRUCTORS)
+#include <stdexcept>
+#include <cstdint>
+#include <cstdlib>
+#include <stdlib.h>
+
+/* Current CPPUnit offends the honor of C++98 and maybe later versions */
+#if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_EXIT_TIME_DESTRUCTORS || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_GLOBAL_CONSTRUCTORS || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_DEPRECATED_DECLARATIONS || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_SUGGEST_OVERRIDE_BESIDEFUNC || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_SUGGEST_DESTRUCTOR_OVERRIDE_BESIDEFUNC || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_WEAK_VTABLES_BESIDEFUNC || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_DEPRECATED_DYNAMIC_EXCEPTION_SPEC_BESIDEFUNC || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_EXTRA_SEMI_BESIDEFUNC || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_OLD_STYLE_CAST_BESIDEFUNC)
 #pragma GCC diagnostic push
 # ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_GLOBAL_CONSTRUCTORS
 #  pragma GCC diagnostic ignored "-Wglobal-constructors"
@@ -34,13 +40,35 @@
 # ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_EXIT_TIME_DESTRUCTORS
 #  pragma GCC diagnostic ignored "-Wexit-time-destructors"
 # endif
+# ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_DEPRECATED_DECLARATIONS
+#  pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+# endif
+# ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_SUGGEST_OVERRIDE_BESIDEFUNC
+#  pragma GCC diagnostic ignored "-Wsuggest-override"
+# endif
+# ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_SUGGEST_DESTRUCTOR_OVERRIDE_BESIDEFUNC
+#  pragma GCC diagnostic ignored "-Wsuggest-destructor-override"
+# endif
+# ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_WEAK_VTABLES_BESIDEFUNC
+#  pragma GCC diagnostic ignored "-Wweak-vtables"
+# endif
+# ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_DEPRECATED_DYNAMIC_EXCEPTION_SPEC_BESIDEFUNC
+#  pragma GCC diagnostic ignored "-Wdeprecated-dynamic-exception-spec"
+# endif
+# ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_EXTRA_SEMI_BESIDEFUNC
+#  pragma GCC diagnostic ignored "-Wextra-semi"
+# endif
+# ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_OLD_STYLE_CAST_BESIDEFUNC
+#  pragma GCC diagnostic ignored "-Wold-style-cast"
+# endif
+#endif
+#if (defined __clang__) && (defined HAVE_PRAGMA_CLANG_DIAGNOSTIC_IGNORED_DEPRECATED_DECLARATIONS)
+# ifdef HAVE_PRAGMA_CLANG_DIAGNOSTIC_IGNORED_DEPRECATED_DECLARATIONS
+#  pragma clang diagnostic push "-Wdeprecated-declarations"
+# endif
 #endif
 
 #include <cppunit/extensions/HelperMacros.h>
-#include <stdexcept>
-#include <cstdint>
-#include <cstdlib>
-#include <stdlib.h>
 
 namespace nut {
 
@@ -59,11 +87,11 @@ class NutActiveClientTest : public CppUnit::TestFixture
 
 private:
 	/* Fed by caller via envvars: */
-	uint16_t NUT_PORT = 0;
-	std::string NUT_USER = "";
-	std::string NUT_PASS = "";
-	std::string NUT_PRIMARY_DEVICE = "";
-	std::string NUT_SETVAR_DEVICE = "";
+	uint16_t env_NUT_PORT = 0;
+	std::string env_NUT_USER = "";
+	std::string env_NUT_PASS = "";
+	std::string env_NUT_PRIMARY_DEVICE = "";
+	std::string env_NUT_SETVAR_DEVICE = "";
 
 public:
 	void setUp() override;
@@ -97,7 +125,7 @@ strarr stringvector_to_strarr(const std::vector<std::string>& strset);
 
 void NutActiveClientTest::setUp()
 {
-	/* NUT_PORT etc. are provided by external test suite driver */
+	/* NUT_PORT etc. env vars are provided by external test suite driver */
 	char * s;
 
 	s = std::getenv("NUT_PORT");
@@ -106,29 +134,29 @@ void NutActiveClientTest::setUp()
 		if (l < 1 || l > 65535) {
 			throw std::runtime_error("NUT_PORT specified by caller is out of range");
 		}
-		NUT_PORT = static_cast<uint16_t>(l);
+		env_NUT_PORT = static_cast<uint16_t>(l);
 	} else {
 		throw std::runtime_error("NUT_PORT not specified by caller, NIT should call this test");
 	}
 
 	s = std::getenv("NUT_USER");
 	if (s) {
-		NUT_USER = s;
+		env_NUT_USER = s;
 	} // else stays empty
 
 	s = std::getenv("NUT_PASS");
 	if (s) {
-		NUT_PASS = s;
+		env_NUT_PASS = s;
 	} // else stays empty
 
 	s = std::getenv("NUT_PRIMARY_DEVICE");
 	if (s) {
-		NUT_PRIMARY_DEVICE = s;
+		env_NUT_PRIMARY_DEVICE = s;
 	} // else stays empty
 
 	s = std::getenv("NUT_SETVAR_DEVICE");
 	if (s) {
-		NUT_SETVAR_DEVICE = s;
+		env_NUT_SETVAR_DEVICE = s;
 	} // else stays empty
 }
 
@@ -137,7 +165,7 @@ void NutActiveClientTest::tearDown()
 }
 
 void NutActiveClientTest::test_query_ver() {
-	nut::TcpClient c("localhost", NUT_PORT);
+	nut::TcpClient c("localhost", env_NUT_PORT);
 	std::string s;
 
 	std::cerr << "[D] C++ NUT Client lib test running against Data Server at: "
@@ -191,7 +219,7 @@ void NutActiveClientTest::test_query_ver() {
 }
 
 void NutActiveClientTest::test_list_ups() {
-	nut::TcpClient c("localhost", NUT_PORT);
+	nut::TcpClient c("localhost", env_NUT_PORT);
 	std::set<std::string> devs;
 	bool noException = true;
 
@@ -223,12 +251,12 @@ void NutActiveClientTest::test_list_ups() {
 }
 
 void NutActiveClientTest::test_list_ups_clients() {
-	nut::TcpClient c("localhost", NUT_PORT);
+	nut::TcpClient c("localhost", env_NUT_PORT);
 	std::map<std::string, std::set<std::string>> deviceClients;
 	bool noException = true;
 
 	try {
-		c.authenticate(NUT_USER, NUT_PASS);
+		c.authenticate(env_NUT_USER, env_NUT_PASS);
 		std::cerr << "[D] Authenticated without exceptions" << std::endl;
 		/* Note: no high hopes here, credentials are checked by server
 		 * when running critical commands, not at auth request itself */
@@ -240,7 +268,7 @@ void NutActiveClientTest::test_list_ups_clients() {
 	}
 
 	try {
-		c.deviceLogin(NUT_PRIMARY_DEVICE);
+		c.deviceLogin(env_NUT_PRIMARY_DEVICE);
 	}
 	catch(nut::NutException& ex)
 	{
@@ -285,15 +313,15 @@ void NutActiveClientTest::test_list_ups_clients() {
 }
 
 void NutActiveClientTest::test_auth_user() {
-	if (NUT_USER.empty()) {
+	if (env_NUT_USER.empty()) {
 		std::cerr << "[D] SKIPPING test_auth_user()" << std::endl;
 		return;
 	}
 
-	nut::TcpClient c("localhost", NUT_PORT);
+	nut::TcpClient c("localhost", env_NUT_PORT);
 	bool noException = true;
 	try {
-		c.authenticate(NUT_USER, NUT_PASS);
+		c.authenticate(env_NUT_USER, env_NUT_PASS);
 		std::cerr << "[D] Authenticated without exceptions" << std::endl;
 		/* Note: no high hopes here, credentials are checked by server
 		 * when running critical commands, not at auth request itself */
@@ -304,22 +332,22 @@ void NutActiveClientTest::test_auth_user() {
 		noException = false;
 	}
 
-	if (!NUT_SETVAR_DEVICE.empty()) {
+	if (!env_NUT_SETVAR_DEVICE.empty()) {
 		try {
 			TrackingResult tres;
 			TrackingID tid;
 			int i;
 			std::string nutVar = "ups.status"; /* Has a risk of flip-flop with NIT dummy setup */
-			std::string s1 = c.getDeviceVariableValue(NUT_SETVAR_DEVICE, nutVar)[0];
+			std::string s1 = c.getDeviceVariableValue(env_NUT_SETVAR_DEVICE, nutVar)[0];
 			std::string sTest = s1 + "-test";
 
-			std::cerr << "[D] Got initial device '" << NUT_SETVAR_DEVICE
+			std::cerr << "[D] Got initial device '" << env_NUT_SETVAR_DEVICE
 				<< "' variable '" << nutVar << "' value: " << s1 << std::endl;
 			CPPUNIT_ASSERT_MESSAGE(
 				"Did not expect empty value here",
 				!s1.empty());
 
-			tid = c.setDeviceVariable(NUT_SETVAR_DEVICE, nutVar, sTest);
+			tid = c.setDeviceVariable(env_NUT_SETVAR_DEVICE, nutVar, sTest);
 			while ( (tres = c.getTrackingResult(tid)) == PENDING) {
 				usleep(100);
 			}
@@ -338,7 +366,7 @@ void NutActiveClientTest::test_auth_user() {
 			 */
 			std::string s2;
 			for (i = 0; i < 100 ; i++) {
-				s2 = c.getDeviceVariableValue(NUT_SETVAR_DEVICE, nutVar)[0];
+				s2 = c.getDeviceVariableValue(env_NUT_SETVAR_DEVICE, nutVar)[0];
 				if (s2 == sTest)
 					break;
 				usleep(100000);
@@ -348,7 +376,7 @@ void NutActiveClientTest::test_auth_user() {
 				<< std::endl;
 
 			/* Fix it back */
-			tid = c.setDeviceVariable(NUT_SETVAR_DEVICE, nutVar, s1);
+			tid = c.setDeviceVariable(env_NUT_SETVAR_DEVICE, nutVar, s1);
 			while ( (tres = c.getTrackingResult(tid)) == PENDING) {
 				usleep(100);
 			}
@@ -359,7 +387,7 @@ void NutActiveClientTest::test_auth_user() {
 			}
 			std::string s3;
 			for (i = 0; i < 100 ; i++) {
-				s3 = c.getDeviceVariableValue(NUT_SETVAR_DEVICE, nutVar)[0];
+				s3 = c.getDeviceVariableValue(env_NUT_SETVAR_DEVICE, nutVar)[0];
 				if (s3 == s1)
 					break;
 				usleep(100000);
@@ -406,15 +434,15 @@ void NutActiveClientTest::test_auth_user() {
 }
 
 void NutActiveClientTest::test_auth_primary() {
-	if (NUT_USER.empty() || NUT_PRIMARY_DEVICE.empty()) {
+	if (env_NUT_USER.empty() || env_NUT_PRIMARY_DEVICE.empty()) {
 		std::cerr << "[D] SKIPPING test_auth_primary()" << std::endl;
 		return;
 	}
 
-	nut::TcpClient c("localhost", NUT_PORT);
+	nut::TcpClient c("localhost", env_NUT_PORT);
 	bool noException = true;
 	try {
-		c.authenticate(NUT_USER, NUT_PASS);
+		c.authenticate(env_NUT_USER, env_NUT_PASS);
 		std::cerr << "[D] Authenticated without exceptions" << std::endl;
 	}
 	catch(nut::NutException& ex)
@@ -425,31 +453,31 @@ void NutActiveClientTest::test_auth_primary() {
 	}
 
 	try {
-		Device d = c.getDevice(NUT_PRIMARY_DEVICE);
+		Device d = c.getDevice(env_NUT_PRIMARY_DEVICE);
 		bool gotPrimary = false;
 		bool gotMaster = false;
 
 		try {
-			c.deviceMaster(NUT_PRIMARY_DEVICE);
+			c.deviceMaster(env_NUT_PRIMARY_DEVICE);
 			gotMaster = true;
 			std::cerr << "[D] Elevated as MASTER without exceptions" << std::endl;
 		}
 		catch(nut::NutException& ex)
 		{
 			std::cerr << "[D] Could not elevate as MASTER for "
-				<< "NUT_PRIMARY_DEVICE " << NUT_PRIMARY_DEVICE << ": "
+				<< "NUT_PRIMARY_DEVICE " << env_NUT_PRIMARY_DEVICE << ": "
 				<< ex.what() << std::endl;
 		}
 
 		try {
-			c.devicePrimary(NUT_PRIMARY_DEVICE);
+			c.devicePrimary(env_NUT_PRIMARY_DEVICE);
 			gotPrimary = true;
 			std::cerr << "[D] Elevated as PRIMARY without exceptions" << std::endl;
 		}
 		catch(nut::NutException& ex)
 		{
 			std::cerr << "[D] Could not elevate as PRIMARY for "
-				<< "NUT_PRIMARY_DEVICE " << NUT_PRIMARY_DEVICE << ": "
+				<< "NUT_PRIMARY_DEVICE " << env_NUT_PRIMARY_DEVICE << ": "
 				<< ex.what() << std::endl;
 		}
 
@@ -458,7 +486,7 @@ void NutActiveClientTest::test_auth_primary() {
 	}
 	catch(nut::NutException& ex)
 	{
-		std::cerr << "[D] NUT_PRIMARY_DEVICE " << NUT_PRIMARY_DEVICE
+		std::cerr << "[D] NUT_PRIMARY_DEVICE " << env_NUT_PRIMARY_DEVICE
 			<< " not found on Data Server: "
 			<< ex.what() << std::endl;
 		noException = false;
@@ -474,6 +502,9 @@ void NutActiveClientTest::test_auth_primary() {
 
 } // namespace nut {}
 
-#if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_EXIT_TIME_DESTRUCTORS || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_GLOBAL_CONSTRUCTORS)
-#pragma GCC diagnostic pop
+#if (defined __clang__) && (defined HAVE_PRAGMA_CLANG_DIAGNOSTIC_IGNORED_DEPRECATED_DECLARATIONS)
+# pragma clang diagnostic pop
+#endif
+#if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_EXIT_TIME_DESTRUCTORS || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_GLOBAL_CONSTRUCTORS || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_DEPRECATED_DECLARATIONS || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_SUGGEST_OVERRIDE_BESIDEFUNC || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_SUGGEST_DESTRUCTOR_OVERRIDE_BESIDEFUNC || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_WEAK_VTABLES_BESIDEFUNC || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_DEPRECATED_DYNAMIC_EXCEPTION_SPEC_BESIDEFUNC || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_EXTRA_SEMI_BESIDEFUNC || defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_OLD_STYLE_CAST_BESIDEFUNC)
+# pragma GCC diagnostic pop
 #endif
