@@ -1,7 +1,7 @@
-/*  generic_gpio_utest.c - gpio NUT driver code test tool
+/*  tests/generic_gpio_utest.c - gpio NUT driver code test tool
  *
  *  Copyright (C)
- *	2023       	Modris Berzonis <modrisb@apollo.lv>
+ *	2023 - 2025		Modris Berzonis <modrisb@apollo.lv>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 
 extern struct gpioups_t *gpioupsfd;
 
-static int done=0;
+static int done=1;
 static int test_with_exit;
 static jmp_buf env_buffer;
 static FILE * testData;
@@ -101,7 +101,7 @@ int get_test_status(struct gpioups_t *result, int on_fail_path) {
 
 	for (i=0; i<result->rulesCount; i++) {
 		fEof=fscanf(testData, "%s", stateName);
-		if(!strcmp(result->rules[i]->stateName,stateName)) {
+		if(strcmp(result->rules[i]->stateName,stateName)) {
 			cases_failed++;
 			printf("expecting stateName %s, got %s for rule %d\n", stateName, result->rules[i]->stateName, i);
 			return 1;
@@ -137,13 +137,37 @@ void exit(int code)
 }
 
 int main(int argc, char **argv) {
-	int jmp_result;
+	int jmp_result, lvl;
 	char rules[128];
 	char testType[128];
 	char testDescFileNameBuf[LARGEBUF];
-	char *testDescFileName = "generic_gpio_test.txt";
+	char *testDescFileName = "generic_gpio_test.txt", *s;
 	unsigned int i;
+	unsigned long version = WITH_LIBGPIO_VERSION;
+	printf("Tests running for libgpiod library version %lu\n", version);
 
+	s = getenv("NUT_DEBUG_LEVEL");
+	if (s && str_to_int(s, &lvl, 10) && lvl > 0) {
+		nut_debug_level = lvl;
+	}
+
+#if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && ( (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_ADDRESS) || (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_UNREACHABLE_CODE))
+# pragma GCC diagnostic push
+#endif
+#ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_ADDRESS
+# pragma GCC diagnostic ignored "-Waddress"
+#endif
+#ifdef HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_UNREACHABLE_CODE
+# pragma GCC diagnostic ignored "-Wunreachable-code"
+#endif
+/* #if !(defined ENABLE_SHARED_PRIVATE_LIBS) || !ENABLE_SHARED_PRIVATE_LIBS */
+	default_register_upsdrv_callbacks();
+/* #endif */
+#if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && ( (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_ADDRESS) || (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_UNREACHABLE_CODE))
+# pragma GCC diagnostic pop
+#endif
+
+	done=0;
 	test_with_exit=0;
 
 	if(argc==2) {
@@ -152,6 +176,10 @@ int main(int argc, char **argv) {
 
 	testData = fopen (testDescFileName, "r");
 	if(!testData) {
+		/* FIXME NUT_WIN32_INCOMPLETE : Actually modern Windows
+		 *  supports both slashes, but revise this code so we do
+		 *  not mix them (maybe enforce a specific one - e.g. some
+		 *  other code does replace / with \ in common.c) */
 		if (!strchr(testDescFileName, '/')) {
 			/* "srcdir" may be set by automake test harness, see
 			 * https://www.gnu.org/software/automake/manual/1.12.2/html_node/Scripts_002dbased-Testsuites.html
@@ -210,25 +238,25 @@ int main(int argc, char **argv) {
 #endif
 		if(fEof!=EOF) {
 			if(!strcmp(testType, "rules")) {
-				struct gpioups_t *upsfdtest=xcalloc(sizeof(*upsfdtest),1);
+				struct gpioups_t *upsfdtest = xcalloc(1, sizeof(*upsfdtest));
+				/* NOTE: here and below, freed by generic_gpio_close(&upsfdtest) */
 				jmp_result = setjmp(env_buffer);
 				if(jmp_result) {	/* test case  exiting */
-					generic_gpio_close(upsfdtest);
 					printf("%s %s test rule %u [%s]\n", pass_fail[get_test_status(upsfdtest, 1)], testType, i, rules);
 				} else { /* run test case */
 					get_ups_rules(upsfdtest, (unsigned char *)rules);
-					generic_gpio_close(upsfdtest);
 					printf("%s %s test rule %u [%s]\n", pass_fail[get_test_status(upsfdtest, 0)], testType, i, rules);
 				}
+				generic_gpio_close(&upsfdtest);
 			}
 			if(!strcmp(testType, "states")) {
 				int expectedStateValue;
 				int calculatedStateValue;
-				struct gpioups_t *upsfdtest=xcalloc(sizeof(*upsfdtest),1);
+				struct gpioups_t *upsfdtest = xcalloc(1, sizeof(*upsfdtest));
 				int j;
 
 				get_ups_rules(upsfdtest, (unsigned char *)rules);
-				upsfdtest->upsLinesStates=xcalloc(sizeof(int),upsfdtest->upsLinesCount);
+				upsfdtest->upsLinesStates = xcalloc(upsfdtest->upsLinesCount, sizeof(int));
 				for (j=0; j < upsfdtest->upsLinesCount; j++) {
 					fEof=fscanf(testData, "%d", &upsfdtest->upsLinesStates[j]);
 				}
@@ -248,14 +276,14 @@ int main(int argc, char **argv) {
 						cases_failed++;
 					}
 				}
-				generic_gpio_close(upsfdtest);
+				generic_gpio_close(&upsfdtest);
 			}
 			if(!strcmp(testType, "update")) {
 				char upsStatus[256];
 				char chargeStatus[256];
 				char chargeLow[256];
 				char charge[256];
-				struct gpioups_t *upsfdtest=xcalloc(sizeof(*upsfdtest),1);
+				struct gpioups_t *upsfdtest = xcalloc(1, sizeof(*upsfdtest));
 				int j;
 
 				/* "volatile" trickery to avoid the likes of:
@@ -268,7 +296,7 @@ int main(int argc, char **argv) {
 				const char * volatile currCharge = NULL;
 
 				get_ups_rules(upsfdtest, (unsigned char *)rules);
-				upsfdtest->upsLinesStates=xcalloc(sizeof(int),upsfdtest->upsLinesCount);
+				upsfdtest->upsLinesStates = xcalloc(upsfdtest->upsLinesCount, sizeof(int));
 				for (j = 0; j < upsfdtest->upsLinesCount; j++) {
 					fEof=fscanf(testData, "%d", &upsfdtest->upsLinesStates[j]);
 				}
@@ -281,7 +309,6 @@ int main(int argc, char **argv) {
 				jmp_result = setjmp(env_buffer);
 				if (jmp_result) {
 					failed=1;
-					generic_gpio_close(upsfdtest);
 				} else {
 					update_ups_states(upsfdtest);
 					currUpsStatus=dstate_getinfo("ups.status");
@@ -292,8 +319,8 @@ int main(int argc, char **argv) {
 					if(!strcmp(chargeStatus,".") && currChargerStatus!=NULL) failed=1;
 					if( strcmp(chargeLow,".") && strcmp(charge,".") && (!currCharge || strcmp(currCharge, charge))) failed=1;
 					if(!strcmp(chargeLow,".") && !strcmp(charge,".") && currCharge!=NULL) failed=1;
-					generic_gpio_close(upsfdtest);
 				}
+				generic_gpio_close(&upsfdtest);
 				printf("%s %s test rule %u [%s] ([%s] %s %s (%s)) ([%s] %s %s)\n",
 					pass_fail[failed], testType, i, rules,
 					upsStatus, chargeStatus, charge, chargeLow,
@@ -326,9 +353,9 @@ int main(int argc, char **argv) {
 				 * because scanf() does not support asterisk for
 				 * width specifier; have to create it on the fly.
 				 */
-				snprintf(fmt, sizeof(fmt), "%%%us", NUT_GPIO_CHIPNAMEBUF-1);
+				snprintf(fmt, sizeof(fmt), "%%%us", (unsigned int)NUT_GPIO_CHIPNAMEBUF-1);
 				fEof=fscanf(testData, fmt, chipNameLocal);
-				snprintf(fmt, sizeof(fmt), "%%%us", NUT_GPIO_SUBTYPEBUF-1);
+				snprintf(fmt, sizeof(fmt), "%%%us", (unsigned int)NUT_GPIO_SUBTYPEBUF-1);
 				fEof=fscanf(testData, fmt, subType);
 #ifdef HAVE_PRAGMAS_FOR_GCC_DIAGNOSTIC_IGNORED_FORMAT_NONLITERAL
 #pragma GCC diagnostic pop
@@ -390,6 +417,11 @@ int main(int argc, char **argv) {
 	fclose(testData);
 	done = 1;
 
+	dstate_free();
+	/* Should be safe if we happen to run this twice for
+	 * generic_gpio_common.c, it only frees driver variables once */
+	upsdrv_cleanup();
+
 	/* Return 0 (exit-code OK, boolean false) if no tests failed and some ran */
 	if ( (cases_failed == 0) && (cases_passed > 0) )
 		return 0;
