@@ -1,6 +1,7 @@
 /*
  *  Copyright (C) 2011 - EATON
  *  Copyright (C) 2016-2021 - EATON - Various threads-related improvements
+ *  Copyright (C) 2020-2024 - Jim Klimov <jimklimov+nut@gmail.com> - support and modernization of codebase
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +21,7 @@
 /*! \file scan_snmp.c
     \brief detect NUT supported SNMP devices
     \author Frederic Bohe <FredericBohe@Eaton.com>
+    \author Jim Klimov <EvgenyKlimov@Eaton.com>
     \author Arnaud Quette <ArnaudQuette@Eaton.com>
     \author Jim Klimov <EvgenyKlimov@eaton.com>
 */
@@ -28,55 +30,89 @@
 #include "nut-scan.h"
 #include "nut_stdint.h"
 
-#ifdef WITH_SNMP
+/* externally visible to nutscan-init */
+int nutscan_unload_snmp_library(void);
+
+#if (defined WITH_SNMP) && WITH_SNMP
 
 #ifndef WIN32
-#include <sys/socket.h>
-#else
-#undef _WIN32_WINNT
-#endif
+# include <sys/socket.h>
+#else	/* WIN32 */
+# undef _WIN32_WINNT
+#endif	/* WIN32 */
 
-#include <stdio.h>
 #include <string.h>
+#include <stdio.h>
 #include <ltdl.h>
 
 /* workaround for buggy Net-SNMP config
  * from drivers/snmp-ups.h */
 #ifdef PACKAGE_BUGREPORT
-#undef PACKAGE_BUGREPORT
+# undef PACKAGE_BUGREPORT
 #endif
 
 #ifdef PACKAGE_NAME
-#undef PACKAGE_NAME
+# undef PACKAGE_NAME
 #endif
 
 #ifdef PACKAGE_VERSION
-#undef PACKAGE_VERSION
+# undef PACKAGE_VERSION
 #endif
 
 #ifdef PACKAGE_STRING
-#undef PACKAGE_STRING
+# undef PACKAGE_STRING
 #endif
 
 #ifdef PACKAGE_TARNAME
-#undef PACKAGE_TARNAME
+# undef PACKAGE_TARNAME
 #endif
 
+#ifdef PACKAGE_URL
+# undef PACKAGE_URL
+#endif
+
+#if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_UNUSED_PARAMETER)
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wunused-parameter"
+#endif
+#ifdef __clang__
+# pragma clang diagnostic push
+# pragma clang diagnostic ignored "-Wunused-parameter"
+#endif
+/* These tend to have inlined API implementations as empty braces,
+ * causing warnings about unused parameters.
+ */
 #include <net-snmp/net-snmp-config.h>
 #include <net-snmp/net-snmp-includes.h>
+
+#ifdef __clang__
+# pragma clang diagnostic pop
+#endif
+#if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_UNUSED_PARAMETER)
+# pragma GCC diagnostic pop
+#endif
+
 #include "nutscan-snmp.h"
 
 /* Address API change */
 #if ( ! NUT_HAVE_LIBNETSNMP_usmAESPrivProtocol ) && ( ! defined usmAESPrivProtocol )
-#define USMAESPRIVPROTOCOL "usmAES128PrivProtocol"
-#define USMAESPRIVPROTOCOL_PTR usmAES128PrivProtocol
+# define USMAESPRIVPROTOCOL "usmAES128PrivProtocol"
+# define USMAESPRIVPROTOCOL_PTR usmAES128PrivProtocol
 #else
-#define USMAESPRIVPROTOCOL "usmAESPrivProtocol"
-#define USMAESPRIVPROTOCOL_PTR usmAESPrivProtocol
+# define USMAESPRIVPROTOCOL "usmAESPrivProtocol"
+# define USMAESPRIVPROTOCOL_PTR usmAESPrivProtocol
 #endif
 
 #define SysOID ".1.3.6.1.2.1.1.2.0"
 
+/* This variable collects device(s) from a sequential or parallel scan,
+ * is returned to caller, and cleared to allow subsequent independent scans */
+static nutscan_device_t * dev_ret = NULL;
+#ifdef HAVE_PTHREAD
+static pthread_mutex_t dev_mutex;
+#endif
+static useconds_t g_usec_timeout ;
+
 /* use explicit booleans */
 #ifndef FALSE
 typedef enum ebool { FALSE = 0, TRUE } bool_t;
@@ -84,17 +120,13 @@ typedef enum ebool { FALSE = 0, TRUE } bool_t;
 typedef int bool_t;
 #endif
 
-static nutscan_device_t * dev_ret = NULL;
-#ifdef HAVE_PTHREAD
-static pthread_mutex_t dev_mutex;
-#endif
-static useconds_t g_usec_timeout ;
-
 #ifndef WITH_SNMP_STATIC
 /* dynamic link library stuff */
 static lt_dlhandle dl_handle = NULL;
 static const char *dl_error = NULL;
+static char *dl_saved_libname = NULL;
 #endif	/* WITH_SNMP_STATIC */
+static int nut_initialized_snmp = 0;
 
 static void (*nut_init_snmp)(const char *type);
 static void (*nut_snmp_sess_init)(netsnmp_session * session);
@@ -155,12 +187,27 @@ static oid *nut_usmHMAC256SHA384AuthProtocol;
 static oid *nut_usmHMAC384SHA512AuthProtocol;
 #endif
 
-/* return 0 on error; visible externally */
-int nutscan_load_snmp_library(const char *libname_path);
+/* Return 0 on success, -1 on error e.g. "was not loaded";
+ * other values may be possible if lt_dlclose() errors set them;
+ * visible externally */
+#ifndef WITH_SNMP_STATIC
+int nutscan_unload_library(int *avail, lt_dlhandle *pdl_handle, char **libpath);
+#endif
+int nutscan_unload_snmp_library(void)
+{
+#if (defined WITH_SNMP_STATIC) && WITH_SNMP_STATIC
+	return 0;
+#else
+	nut_initialized_snmp = 0;
+	return nutscan_unload_library(&nutscan_avail_snmp, &dl_handle, &dl_saved_libname);
+#endif
+}
 
+/* Return 0 on error; visible externally */
+int nutscan_load_snmp_library(const char *libname_path);
 int nutscan_load_snmp_library(const char *libname_path)
 {
-#ifdef WITH_SNMP_STATIC
+#if (defined WITH_SNMP_STATIC) && WITH_SNMP_STATIC
 	/* With MinGW, the netsnmp library may be linked statically (no dll) */
 	NUT_UNUSED_VARIABLE(libname_path);
 
@@ -255,12 +302,12 @@ int nutscan_load_snmp_library(const char *libname_path)
 	}
 
 	if (libname_path == NULL) {
-		upsdebugx(1, "SNMP library not found. SNMP search disabled");
+		upsdebugx(0, "SNMP library not found. SNMP search disabled.");
 		return 0;
 	}
 
 	if (lt_dlinit() != 0) {
-		upsdebugx(1, "Error initializing lt_init");
+		upsdebugx(0, "%s: Error initializing lt_dlinit", __func__);
 		return 0;
 	}
 
@@ -270,7 +317,9 @@ int nutscan_load_snmp_library(const char *libname_path)
 		goto err;
 	}
 
-	lt_dlerror();	/* Clear any existing error */
+	/* Clear any existing error */
+	lt_dlerror();
+
 	*(void **) (&nut_init_snmp) = lt_dlsym(dl_handle, "init_snmp");
 	if ((dl_error = lt_dlerror()) != NULL) {
 		goto err;
@@ -431,17 +480,25 @@ int nutscan_load_snmp_library(const char *libname_path)
 	}
 #endif /* NUT_HAVE_LIBNETSNMP_usmHMAC384SHA512AuthProtocol */
 
-#endif	/* WITH_SNMP_STATIC */
+	if (dl_saved_libname)
+		free(dl_saved_libname);
+	dl_saved_libname = xstrdup(libname_path);
+
+#endif	/* not WITH_SNMP_STATIC */
 
 	return 1;
 
 #ifndef WITH_SNMP_STATIC
 err:
-	fprintf(stderr,
-		"Cannot load SNMP library (%s) : %s. SNMP search disabled.\n",
+	upsdebugx(0,
+		"Cannot load SNMP library (%s) : %s. SNMP search disabled.",
 		libname_path, dl_error);
 	dl_handle = (void *)1;
 	lt_dlexit();
+	if (dl_saved_libname) {
+		free(dl_saved_libname);
+		dl_saved_libname = NULL;
+	}
 	return 0;
 #endif	/* not WITH_SNMP_STATIC */
 }
@@ -461,6 +518,8 @@ static void scan_snmp_add_device(nutscan_snmp_t * sec, struct snmp_pdu *response
 	dev = nutscan_new_device();
 	dev->type = TYPE_SNMP;
 	dev->driver = strdup("snmp-ups");
+	/* FIXME: Should the IPv6 address here be bracketed?
+	 *  Does our driver support the notation? */
 	dev->port = strdup(session->peername);
 	if (response != NULL) {
 		buf = malloc (response->variables->val_len + 1);
@@ -639,15 +698,16 @@ static int init_session(struct snmp_session * snmp_sess, nutscan_snmp_t * sec)
 		else if (strcmp(sec->secLevel, "authPriv") == 0)
 			snmp_sess->securityLevel = SNMP_SEC_LEVEL_AUTHPRIV;
 		else {
-			fprintf(stderr,
-				"Bad SNMPv3 securityLevel: %s\n",
-				sec->secLevel);
+			upsdebugx(0, "WARNING: %s: "
+				"Bad SNMPv3 securityLevel: %s",
+				__func__, sec->secLevel);
 			return 0;
 		}
 
 		/* Security name */
 		if (sec->secName == NULL) {
-			fprintf(stderr, "securityName is required for SNMPv3\n");
+			upsdebugx(0, "WARNING: %s: securityName is required for SNMPv3",
+				__func__);
 			return 0;
 		}
 		snmp_sess->securityName = strdup(sec->secName);
@@ -662,20 +722,20 @@ static int init_session(struct snmp_session * snmp_sess, nutscan_snmp_t * sec)
 		switch (snmp_sess->securityLevel) {
 			case SNMP_SEC_LEVEL_AUTHNOPRIV:
 				if (sec->authPassword == NULL) {
-					fprintf(stderr,
+					upsdebugx(0, "WARNING: %s: "
 						"authPassword is required "
-						"for SNMPv3 in %s mode\n",
-						sec->secLevel);
+						"for SNMPv3 in %s mode",
+						__func__, sec->secLevel);
 					return 0;
 				}
 				break;
 			case SNMP_SEC_LEVEL_AUTHPRIV:
 				if ((sec->authPassword == NULL) ||
 					(sec->privPassword == NULL)) {
-					fprintf(stderr,
+					upsdebugx(0, "WARNING: %s: "
 						"authPassword and privPassword are "
-						"required for SNMPv3 in %s mode\n",
-						sec->secLevel);
+						"required for SNMPv3 in %s mode",
+						__func__, sec->secLevel);
 					return 0;
 				}
 				break;
@@ -737,9 +797,9 @@ static int init_session(struct snmp_session * snmp_sess, nutscan_snmp_t * sec)
 #else
 			{
 #endif
-				fprintf(stderr,
-					"Bad SNMPv3 authProtocol: %s\n",
-					sec->authProtocol);
+				upsdebugx(0, "WARNING: %s: "
+					"Bad SNMPv3 authProtocol: %s",
+					__func__, sec->authProtocol);
 				return 0;
 			}
 		}
@@ -759,8 +819,8 @@ static int init_session(struct snmp_session * snmp_sess, nutscan_snmp_t * sec)
 #if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && ( (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_TYPE_LIMITS) || (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_TAUTOLOGICAL_CONSTANT_OUT_OF_RANGE_COMPARE) )
 # pragma GCC diagnostic pop
 #endif
-			fprintf(stderr, "Bad SNMPv3 securityAuthProtoLen: %" PRIuSIZE,
-				snmp_sess->securityAuthProtoLen);
+			upsdebugx(0, "WARNING: %s: Bad SNMPv3 securityAuthProtoLen: %" PRIuSIZE,
+				__func__, snmp_sess->securityAuthProtoLen);
 			return 0;
 		}
 		if ((*nut_generate_Ku)(snmp_sess->securityAuthProto,
@@ -771,9 +831,10 @@ static int init_session(struct snmp_session * snmp_sess, nutscan_snmp_t * sec)
 					&snmp_sess->securityAuthKeyLen)
 					!= SNMPERR_SUCCESS
 		) {
-			fprintf(stderr,
+			upsdebugx(0, "WARNING: %s: "
 				"Error generating Ku from "
-				"authentication pass phrase\n");
+				"authentication pass phrase",
+				__func__);
 			return 0;
 		}
 
@@ -824,9 +885,9 @@ static int init_session(struct snmp_session * snmp_sess, nutscan_snmp_t * sec)
 #else
 			{
 #endif
-				fprintf(stderr,
-					"Bad SNMPv3 privProtocol: %s\n",
-					sec->privProtocol);
+				upsdebugx(0, "WARNING: %s: "
+					"Bad SNMPv3 privProtocol: %s",
+					__func__, sec->privProtocol);
 				return 0;
 			}
 		}
@@ -847,8 +908,8 @@ static int init_session(struct snmp_session * snmp_sess, nutscan_snmp_t * sec)
 #if (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_PUSH_POP) && ( (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_TYPE_LIMITS) || (defined HAVE_PRAGMA_GCC_DIAGNOSTIC_IGNORED_TAUTOLOGICAL_CONSTANT_OUT_OF_RANGE_COMPARE) )
 # pragma GCC diagnostic pop
 #endif
-			fprintf(stderr, "Bad SNMPv3 securityAuthProtoLen: %" PRIuSIZE,
-				snmp_sess->securityAuthProtoLen);
+			upsdebugx(0, "WARNING: %s: Bad SNMPv3 securityAuthProtoLen: %" PRIuSIZE,
+				__func__, snmp_sess->securityAuthProtoLen);
 			return 0;
 		}
 		if ((*nut_generate_Ku)(snmp_sess->securityAuthProto,
@@ -859,9 +920,10 @@ static int init_session(struct snmp_session * snmp_sess, nutscan_snmp_t * sec)
 					&snmp_sess->securityPrivKeyLen)
 					!= SNMPERR_SUCCESS
 		) {
-			fprintf(stderr,
+			upsdebugx(0, "WARNING: %s: "
 				"Error generating Ku from "
-				"private pass phrase\n");
+				"private pass phrase",
+				__func__);
 			return 0;
 		}
 
@@ -870,7 +932,17 @@ static int init_session(struct snmp_session * snmp_sess, nutscan_snmp_t * sec)
 	return 1;
 }
 
-static void * try_SysOID(void * arg)
+static void * wrap_nut_snmp_sess_open(struct snmp_session *session)
+{
+	/* Open the session */
+	return (*nut_snmp_sess_open)(session); /* establish the session */
+}
+
+/* Performs a (parallel-able) SNMP protocol scan of one remote host.
+ * Returns NULL, updates global dev_ret when a scan is successful.
+ * FREES the caller's copy of "sec" and "peername" in it, if applicable.
+ */
+static void * try_SysOID_thready(void * arg)
 {
 	struct snmp_session snmp_sess;
 	void * handle;
@@ -895,7 +967,7 @@ static void * try_SysOID(void * arg)
 	snmp_sess.timeout = (long)g_usec_timeout;
 
 	/* Open the session */
-	handle = (*nut_snmp_sess_open)(&snmp_sess); /* establish the session */
+	handle = wrap_nut_snmp_sess_open(&snmp_sess); /* establish the session */
 	if (handle == NULL) {
 		upsdebugx(2,
 			"Failed to open SNMP session for %s",
@@ -916,7 +988,7 @@ static void * try_SysOID(void * arg)
 	pdu = (*nut_snmp_pdu_create)(SNMP_MSG_GET);
 
 	if (pdu == NULL) {
-		fprintf(stderr, "Not enough memory\n");
+		upsdebugx(0, "%s: Memory allocation error", __func__);
 		(*nut_snmp_sess_close)(handle);
 		goto try_SysOID_free;
 	}
@@ -1001,37 +1073,63 @@ try_SysOID_free:
 	return NULL;
 }
 
+static void init_snmp_once(void)
+{
+	/* Initialize the SNMP library */
+	if (!nut_initialized_snmp) {
+		(*nut_init_snmp)("nut-scanner");
+		nut_initialized_snmp = 1;
+	}
+}
+
 nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip,
                                      useconds_t usec_timeout, nutscan_snmp_t * sec)
+{
+	nutscan_device_t	*ndret;
+	nutscan_ip_range_list_t irl;
+
+	nutscan_init_ip_ranges(&irl);
+	nutscan_add_ip_range(&irl, (char *)start_ip, (char *)stop_ip);
+
+	ndret = nutscan_scan_ip_range_snmp(&irl, usec_timeout, sec);
+
+	/* Avoid nuking caller's strings here */
+	irl.ip_ranges->start_ip = NULL;
+	irl.ip_ranges->end_ip = NULL;
+	nutscan_free_ip_ranges(&irl);
+
+	return ndret;
+}
+
+nutscan_device_t * nutscan_scan_ip_range_snmp(nutscan_ip_range_list_t * irl,
+                                     useconds_t usec_timeout, nutscan_snmp_t * sec)
 {
 	bool_t pass = TRUE; /* Track that we may spawn a scanning thread */
 	nutscan_device_t * result;
 	nutscan_snmp_t * tmp_sec;
-	nutscan_ip_iter_t ip;
+	nutscan_ip_range_list_iter_t ip;
 	char * ip_str = NULL;
+
 #ifdef HAVE_PTHREAD
-# ifdef HAVE_SEMAPHORE
+# if (defined HAVE_SEMAPHORE_UNNAMED) || (defined HAVE_SEMAPHORE_NAMED)
 	sem_t * semaphore = nutscan_semaphore();
+#  if (defined HAVE_SEMAPHORE_UNNAMED)
 	sem_t   semaphore_scantype_inst;
 	sem_t * semaphore_scantype = &semaphore_scantype_inst;
-# endif /* HAVE_SEMAPHORE */
-
-# ifdef WIN32
-	WSADATA WSAdata;
-	WSAStartup(2,&WSAdata);
-	atexit((void(*)(void))WSACleanup);
-# endif
-
+#  elif (defined HAVE_SEMAPHORE_NAMED)
+	sem_t * semaphore_scantype = NULL;
+#  endif
+# endif /* HAVE_SEMAPHORE_UNNAMED || HAVE_SEMAPHORE_NAMED */
 	pthread_t thread;
 	nutscan_thread_t * thread_array = NULL;
 	size_t thread_count = 0, i;
-# if (defined HAVE_PTHREAD_TRYJOIN) || (defined HAVE_SEMAPHORE)
+# if (defined HAVE_PTHREAD_TRYJOIN) || (defined HAVE_SEMAPHORE_UNNAMED) || (defined HAVE_SEMAPHORE_NAMED)
 	size_t  max_threads_scantype = max_threads_netsnmp;
 # endif
 
 	pthread_mutex_init(&dev_mutex, NULL);
 
-# ifdef HAVE_SEMAPHORE
+# if (defined HAVE_SEMAPHORE_UNNAMED) || (defined HAVE_SEMAPHORE_NAMED)
 	if (max_threads_scantype > 0) {
 #ifdef HAVE_PRAGMAS_FOR_GCC_DIAGNOSTIC_IGNORED_UNREACHABLE_CODE
 #pragma GCC diagnostic push
@@ -1052,13 +1150,26 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 #pragma GCC diagnostic pop
 #endif
 			upsdebugx(1,
-				"WARNING: %s: Limiting max_threads_scantype to range acceptable for sem_init()",
+				"WARNING: %s: Limiting max_threads_scantype to range acceptable for " REPORT_SEM_INIT_METHOD "()",
 				__func__);
 			max_threads_scantype = UINT_MAX - 1;
 		}
-		sem_init(semaphore_scantype, 0, (unsigned int)max_threads_scantype);
+
+		upsdebugx(4, "%s: " REPORT_SEM_INIT_METHOD "() for %" PRIuSIZE " threads", __func__, max_threads_scantype);
+#  if (defined HAVE_SEMAPHORE_UNNAMED)
+		if (sem_init(semaphore_scantype, 0, (unsigned int)max_threads_scantype)) {
+			upsdebug_with_errno(4, "%s: " REPORT_SEM_INIT_METHOD "() failed", __func__);
+			max_threads_scantype = 0;
+		}
+#  elif (defined HAVE_SEMAPHORE_NAMED)
+		if (SEM_FAILED == (semaphore_scantype = sem_open(SEMNAME_SNMP, O_CREAT, 0644, (unsigned int)max_threads_scantype))) {
+			upsdebug_with_errno(4, "%s: " REPORT_SEM_INIT_METHOD "() failed", __func__);
+			semaphore_scantype = NULL;
+			max_threads_scantype = 0;
+		}
+#  endif
 	}
-# endif /* HAVE_SEMAPHORE */
+# endif /* HAVE_SEMAPHORE_UNNAMED || HAVE_SEMAPHORE_NAMED */
 
 #endif /* HAVE_PTHREAD */
 
@@ -1066,18 +1177,35 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 		return NULL;
 	}
 
+	if (irl == NULL || irl->ip_ranges == NULL) {
+		return NULL;
+	}
+
+	if (!irl->ip_ranges->start_ip) {
+		upsdebugx(1, "%s: no starting IP address specified", __func__);
+	} else if (irl->ip_ranges_count == 1
+		&& (irl->ip_ranges->start_ip == irl->ip_ranges->end_ip
+		    || !strcmp(irl->ip_ranges->start_ip, irl->ip_ranges->end_ip)
+	)) {
+		upsdebugx(1, "%s: Scanning SNMP for single IP address: %s",
+			__func__, irl->ip_ranges->start_ip);
+	} else {
+		upsdebugx(1, "%s: Scanning SNMP for IP address range(s): %s",
+			__func__, nutscan_stringify_ip_ranges(irl));
+	}
+
 	g_usec_timeout = usec_timeout;
 
-	/* Force numeric OIDs resolution (ie, do not resolve to textual names)
+	/* Force numeric OIDs resolution (i.e., do not resolve to textual names)
 	 * This is mostly for the convenience of debug output */
 	if (nut_snmp_out_toggle_options("n") != NULL) {
 		upsdebugx(1, "Failed to enable numeric OIDs resolution");
 	}
 
 	/* Initialize the SNMP library */
-	(*nut_init_snmp)("nut-scanner");
+	init_snmp_once();
 
-	ip_str = nutscan_ip_iter_init(&ip, start_ip, stop_ip);
+	ip_str = nutscan_ip_ranges_iter_init(&ip, irl);
 
 	while (ip_str != NULL) {
 #ifdef HAVE_PTHREAD
@@ -1088,7 +1216,7 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 		 * for below in pthread_join()...
 		 */
 
-# ifdef HAVE_SEMAPHORE
+# if (defined HAVE_SEMAPHORE_UNNAMED) || (defined HAVE_SEMAPHORE_NAMED)
 		/* Just wait for someone to free a semaphored slot,
 		 * if none are available, and then/otherwise grab one
 		 */
@@ -1100,8 +1228,22 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 			sem_wait(semaphore);
 			pass = TRUE;
 		} else {
-			pass = ((max_threads_scantype == 0 || sem_trywait(semaphore_scantype) == 0) &&
-			        sem_trywait(semaphore) == 0);
+			/* If successful (the lock was acquired),
+			 * sem_wait() and sem_trywait() will return 0.
+			 * Otherwise, -1 is returned and errno is set,
+			 * and the state of the semaphore is unchanged.
+			 */
+			int	stwST = sem_trywait(semaphore_scantype);
+			int	stwS  = sem_trywait(semaphore);
+			pass = ((max_threads_scantype == 0 || stwST == 0) && stwS == 0);
+			upsdebugx(4, "%s: max_threads_scantype=%" PRIuSIZE
+				" curr_threads=%" PRIuSIZE
+				" thread_count=%" PRIuSIZE
+				" stwST=%d stwS=%d pass=%d",
+				__func__, max_threads_scantype,
+				curr_threads, thread_count,
+				stwST, stwS, pass
+			);
 		}
 # else
 #  ifdef HAVE_PTHREAD_TRYJOIN
@@ -1124,6 +1266,7 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 				"(launched overall: %" PRIuSIZE "), "
 				"waiting until some would finish",
 				__func__, curr_threads, thread_count);
+
 			while (curr_threads >= max_threads
 			   || (curr_threads >= max_threads_scantype && max_threads_scantype > 0)
 			) {
@@ -1133,7 +1276,7 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 					if (!thread_array[i].active) continue;
 
 					pthread_mutex_lock(&threadcount_mutex);
-					upsdebugx(3, "%s: Trying to join thread #%i...", __func__, i);
+					upsdebugx(3, "%s: Trying to join thread #%" PRIuSIZE "...", __func__, i);
 					ret = pthread_tryjoin_np(thread_array[i].thread, NULL);
 					switch (ret) {
 						case ESRCH:     /* No thread with the ID thread could be found - already "joined"? */
@@ -1172,19 +1315,25 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 			}
 			upsdebugx(2, "%s: proceeding with scan", __func__);
 		}
+
 		/* NOTE: No change to default "pass" in this ifdef:
 		 * if we got to this line, we have a slot to use */
 #  endif /* HAVE_PTHREAD_TRYJOIN */
-# endif  /* HAVE_SEMAPHORE */
+# endif  /* HAVE_SEMAPHORE_UNNAMED || HAVE_SEMAPHORE_NAMED */
 #endif   /* HAVE_PTHREAD */
 
 		if (pass) {
 			tmp_sec = malloc(sizeof(nutscan_snmp_t));
+			if (tmp_sec == NULL) {
+				upsdebugx(0, "%s: Memory allocation error", __func__);
+				break;
+			}
+
 			memcpy(tmp_sec, sec, sizeof(nutscan_snmp_t));
 			tmp_sec->peername = ip_str;
 
 #ifdef HAVE_PTHREAD
-			if (pthread_create(&thread, NULL, try_SysOID, (void*)tmp_sec) == 0) {
+			if (pthread_create(&thread, NULL, try_SysOID_thready, (void*)tmp_sec) == 0) {
 				nutscan_thread_t	*new_thread_array;
 # ifdef HAVE_PTHREAD_TRYJOIN
 				pthread_mutex_lock(&threadcount_mutex);
@@ -1208,20 +1357,26 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 				pthread_mutex_unlock(&threadcount_mutex);
 # endif /* HAVE_PTHREAD_TRYJOIN */
 			}
-#else   /* not HAVE_PTHREAD */
-			try_SysOID((void *)tmp_sec);
+#else   /* if not HAVE_PTHREAD */
+			try_SysOID_thready(tmp_sec);
 #endif  /* if HAVE_PTHREAD */
-/*			free(ip_str); */ /* Do not free() here - seems to cause a double-free instead */
-			ip_str = nutscan_ip_iter_inc(&ip);
-/*			free(tmp_sec); */
+
+			/* Prepare the next iteration; note that
+			 * try_SysOID_thready()
+			 * takes care of freeing "tmp_sec" and its
+			 * reference (NOT strdup!) to "ip_str" as
+			 * peername.
+			 */
+			ip_str = nutscan_ip_ranges_iter_inc(&ip);
 		} else { /* if not pass -- all slots busy */
 #ifdef HAVE_PTHREAD
-# ifdef HAVE_SEMAPHORE
+# if (defined HAVE_SEMAPHORE_UNNAMED) || (defined HAVE_SEMAPHORE_NAMED)
 			/* Wait for all current scans to complete */
 			if (thread_array != NULL) {
-				upsdebugx (2, "%s: Running too many scanning threads, "
+				upsdebugx (2, "%s: Running too many scanning threads (%"
+					PRIuSIZE "), "
 					"waiting until older ones would finish",
-					__func__);
+					__func__, thread_count);
 				for (i = 0; i < thread_count ; i++) {
 					int ret;
 					if (!thread_array[i].active) {
@@ -1250,9 +1405,9 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 			}
 # else
 #  ifdef HAVE_PTHREAD_TRYJOIN
-		/* TODO: Move the wait-loop for TRYJOIN here? */
+			/* TODO: Move the wait-loop for TRYJOIN here? */
 #  endif /* HAVE_PTHREAD_TRYJOIN */
-# endif  /* HAVE_SEMAPHORE */
+# endif  /* HAVE_SEMAPHORE_UNNAMED || HAVE_SEMAPHORE_NAMED */
 #endif   /* HAVE_PTHREAD */
 		} /* if: could we "pass" or not? */
 	} /* while */
@@ -1271,7 +1426,7 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 					__func__, ret);
 			}
 			thread_array[i].active = FALSE;
-# ifdef HAVE_SEMAPHORE
+# if (defined HAVE_SEMAPHORE_UNNAMED) || (defined HAVE_SEMAPHORE_NAMED)
 			sem_post(semaphore);
 			if (max_threads_scantype > 0)
 				sem_post(semaphore_scantype);
@@ -1288,17 +1443,26 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 			}
 			pthread_mutex_unlock(&threadcount_mutex);
 #  endif /* HAVE_PTHREAD_TRYJOIN */
-# endif /* HAVE_SEMAPHORE */
+# endif /* HAVE_SEMAPHORE_UNNAMED || HAVE_SEMAPHORE_NAMED */
 		}
 		free(thread_array);
 		upsdebugx(2, "%s: all threads freed", __func__);
 	}
 	pthread_mutex_destroy(&dev_mutex);
 
-# ifdef HAVE_SEMAPHORE
-	if (max_threads_scantype > 0)
+# if (defined HAVE_SEMAPHORE_UNNAMED) || (defined HAVE_SEMAPHORE_NAMED)
+	if (max_threads_scantype > 0) {
+#  if (defined HAVE_SEMAPHORE_UNNAMED)
 		sem_destroy(semaphore_scantype);
-# endif /* HAVE_SEMAPHORE */
+#  elif (defined HAVE_SEMAPHORE_NAMED)
+		if (semaphore_scantype) {
+			sem_unlink(SEMNAME_SNMP);
+			sem_close(semaphore_scantype);
+			semaphore_scantype = NULL;
+		}
+#  endif
+	}
+# endif /* HAVE_SEMAPHORE_UNNAMED || HAVE_SEMAPHORE_NAMED */
 #endif /* HAVE_PTHREAD */
 
 	result = nutscan_rewind_device(dev_ret);
@@ -1316,7 +1480,23 @@ nutscan_device_t * nutscan_scan_snmp(const char * start_ip, const char * stop_ip
 	NUT_UNUSED_VARIABLE(stop_ip);
 	NUT_UNUSED_VARIABLE(usec_timeout);
 	NUT_UNUSED_VARIABLE(sec);
+
 	return NULL;
 }
 
+/* stub function */
+nutscan_device_t * nutscan_scan_ip_range_snmp(nutscan_ip_range_list_t * irl,
+                                     useconds_t usec_timeout, nutscan_snmp_t * sec)
+{
+	NUT_UNUSED_VARIABLE(irl);
+	NUT_UNUSED_VARIABLE(usec_timeout);
+	NUT_UNUSED_VARIABLE(sec);
+
+	return NULL;
+}
+
+int nutscan_unload_snmp_library(void)
+{
+	return 0;
+}
 #endif /* WITH_SNMP */
